@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -41,7 +41,7 @@ int polltdm=0;
 
 int tdmhit(MAV_object *o, MAV_TDMEvent *ev)
 {
-  printf("hit\n");
+  if (ev->intersects) printf("hit\n");
 
   if (ev->button==1) {
     printf("setting origin as %f %f %f\n", ev->pos.pos.x, ev->pos.pos.y, ev->pos.pos.z);
@@ -165,7 +165,7 @@ int main(int argc, char *argv[])
 /* Initialise the TDM module */
 
   /* Uncomment to specify the dynamically loaded TDM library */
-  /* mav_opt_TDMLib= "/usr/local/TDM-2.0/lib/libtdm-keys.so"; */
+  /* mav_opt_TDMLib= "/usr/local/TDM-2.1/lib/libtdm-keys.so"; */
 
   mav_TDMModuleInit();
 
@@ -245,7 +245,7 @@ int main(int argc, char *argv[])
 /* Set keyboard and TDM event callback */
 
   mav_callbackKeyboardSet(mav_win_all, mav_class_world, key);
-  mav_callbackTDMSet(mav_win_all, mav_class_any, tdmhit);
+  mav_callbackTDMSet(mav_win_all, mav_class_world, tdmhit);
 
 /* Define a set of viewing parameters */
 
