@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -37,9 +37,9 @@ int but(MAV_object *obj, MAV_mouseEvent *me)
   if (me->movement==MAV_PRESSED) {
     /* open appropriate page */
     if (obj==objs[0]) system("netscape -remote \"openURL(http://www.ac3d.org)\"");
-    if (obj==objs[1]) system("netscape -remote \"openURL(http://aig.cs.man.ac.uk/systems/Deva/index.html)\"");
+    if (obj==objs[1]) system("netscape -remote \"openURL(http://aig.cs.man.ac.uk/deva/index.htm)\"");
     if (obj==objs[2]) system("netscape -remote \"openURL(http://aig.cs.man.ac.uk)\"");
-    if (obj==objs[3]) system("netscape -remote \"openURL(http://aig.cs.man.ac.uk/systems/Maverik/index.html)\"");
+    if (obj==objs[3]) system("netscape -remote \"openURL(http://aig.cs.man.ac.uk/maverik/index.htm)\"");
   }
   
   return 1;
