@@ -21,22 +21,26 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
 
 #include "maverik.h"
 #include <stdio.h>
+#include <stdlib.h>
 
 int main(int argc, char *argv[]) 
 {
   MAV_sphere sph;
   MAV_SMS *sms;
   MAV_vector out;
+  float tran=1;
+  int idx;
   
 /* Initialise the Maverik system */
 
+  mav_opt_trans= MAV_TRUE;
   mav_initialise(&argc, argv);
 
 /* Set background colour */
@@ -64,6 +68,18 @@ int main(int argc, char *argv[])
 
   mav_vp_default.eye= mav_vectorSet(0,0,100);
 
+/* Get an unused colour index */
+
+  idx= mav_paletteColourIndexEmptyGet(mav_palette_default);
+  if (idx<0) {
+    fprintf(stderr, "Could not find an unused colour index\n");
+    exit(1);
+  }
+
+/* Dont warn when this colour is redefined */
+
+  mav_paletteColourIndexWarnSet(mav_palette_default, idx, MAV_FALSE);
+
 /* Main loop */
 
   while (1) {
@@ -80,9 +96,15 @@ int main(int argc, char *argv[])
 
     mav_SMSDisplay(mav_win_all, sms);
 
-/* Display some text at a fixed position (0.25, 0.25) */
+/* Define a white colour with a varying transparency */
+  
+    tran-=0.02;
+    if (tran<0) tran=1;
+    mav_paletteColourSet(mav_palette_default, idx, 1, 1, 1, tran);
 
-    mav_stringDisplay(mav_win_all, "* fixed text *", MAV_COLOUR_WHITE, 0, 0.25, 0.25);
+/* Display some text at a fixed position (0.25, 0.25) with this colour */
+
+    mav_stringDisplay(mav_win_all, "* fixed text *", idx, 0, 0.25, 0.25);
 
 /* Calculate the screen position of the sphere centre (0,0,0) and display some text */
 
