@@ -21,14 +21,14 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
 
 #include "maverik.h"
 #include <string.h>
-#if !defined(WIN32) || defined(MAV_CYGWIN)
+#if !defined(WIN32) || defined(__CYGWIN__)
 char *strdup (const char *s1);
 #endif
 
