@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -160,13 +160,27 @@ typedef struct {
   MAV_drawInfo di;
   MAV_drawInfo *dip;
   MAV_matrix mat;
+  MAV_BB bb;
   float dist2;
 } MAV_transObjData;
 
+typedef struct {
+  MAV_window *win;
+  char *s;
+  int col;
+  int font;
+  float x;
+  float y;
+  int justify;
+} MAV_transTextData;
+
 int  mav_objectIsTransparent(MAV_window *w, MAV_object *o);
 void mav_transparentObjectsManage(MAV_window *w, MAV_object *o, MAV_drawInfo *di);
 void mav_transparentObjectsRender(void *ignored);
+void mav_transparentTextManage(MAV_window *w, char *s, int col, int font, float x, float y);
+void mav_transparentTextRender(void *ignored);
 extern MAV_list *mav_transObjList;
+extern MAV_list *mav_transTextList;
 
 typedef struct {
   MAV_window *win;
@@ -184,6 +198,18 @@ extern MAV_list **mav_textureObjList;
 
 
 
+/* Strings */
+
+int  mav_stringLength(MAV_window *w, char *s, int font);
+void mav_stringDisplay(MAV_window *w, char *s, int col, int font, float x, float y);
+void mav_stringDisplayLeft(MAV_window *w, char *s, int col, int font, float x, float y);
+void mav_stringDisplayCentre(MAV_window *w, char *s, int col, int font, float x, float y);
+void mav_stringDisplayRight(MAV_window *w, char *s, int col, int font, float x, float y);
+
+#define mav_stringDisplayCenter mav_stringDisplayCentre 
+
+
+
 /* Options */
 
 extern int mav_opt_trans;
