@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -67,6 +67,10 @@ void mav_gfxWindowStringDisplay(char *s, int font);
 #define MAV_ACCUM_MULT 5
 #define MAV_DLISTS_COMPILE 1
 #define MAV_DLISTS_COMPILE_AND_EXECUTE 2
+#define MAV_FOG_NONE 0
+#define MAV_FOG_LINEAR 1
+#define MAV_FOG_EXP 2
+#define MAV_FOG_EXP2 3
 
 void mav_gfxClipPlaneSet(int id, MAV_clipPlane cp);
 void mav_gfxClipPlanesSet(MAV_clipPlanes *cp);
@@ -92,7 +96,8 @@ void mav_gfxRasterPos2DSet(float x, float y);
 void mav_gfxLineWidthSet(float wd);
 float mav_gfxLineWidthGet(void);
 void mav_gfxLineStippleSet(int factor, unsigned short pattern);
-void mav_gfxVisualInfoGet(int *r, int *g, int *b, int *a, int *d, int *db, int *ar, int *ag, int *ab, int *aa, int *sb, int *msb);
+void mav_gfxFogSet(int type, float data1, float data2, float r, float g, float b);
+int mav_gfxVisualInfoGet(int *r, int *g, int *b, int *a, int *d, int *db, int *ar, int *ag, int *ab, int *aa, int *sb, int *msb);
 void mav_gfxPolygonModeSet(int v);
 void mav_gfxMultiSampleSet(int v);
 void mav_gfxFinish(void);
