@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -37,7 +37,7 @@ extern "C" {
 /* #define constants */
 
 #define MAV_VERSION(X,Y) ((X)*256+(Y))
-#define MAV_THIS_VERSION MAV_VERSION(6,0)
+#define MAV_THIS_VERSION MAV_VERSION(6,1)
 
 #define MAV_FALSE 0
 #define MAV_TRUE 1
@@ -95,7 +95,6 @@ extern "C" {
 #define mav_vectorNormalise mav_vectorNormalize
 #define mav_initialize mav_initialise
 #define mav_initializeNoArgs mav_initialiseNoArgs
-#define mav_stringDisplayCenter mav_stringDisplayCentre 
 
 /* Maverik data types */
 
@@ -198,12 +197,14 @@ typedef struct {
 
 typedef struct {
   int id;
+  int defwarn;
   int defined;
   float colour[4];
 } MAV_colour;
 
 typedef struct {
   int id;
+  int defwarn;
   int defined;
   float ambient[4];
   int localviewer;
@@ -212,6 +213,7 @@ typedef struct {
 typedef struct {
   int id;
   int index;
+  int defwarn;
   int defined;
   float ambient[4];
   float diffuse[4];
@@ -222,6 +224,7 @@ typedef struct {
 
 typedef struct {
   int id;
+  int defwarn;
   int defined;
   float ambient[4];
   float diffuse[4];
@@ -235,6 +238,7 @@ typedef void (*MAV_texEnvFn)(struct MAV_TEXTURE_STRUCT *);
 
 typedef struct MAV_TEXTURE_STRUCT {
   int id;
+  int defwarn;
   int defined;
   int width;
   int height;
@@ -251,18 +255,26 @@ typedef struct MAV_TEXTURE_STRUCT {
 
 typedef struct {
   int id;
+  int defwarn;
   int defined;
   char *name;
   int width[256];
 } MAV_font;
 
 typedef struct {
+  int defwarn;
+  int lm_defwarn;
   MAV_lightingModel lm;
+  int light_defwarn;
   MAV_light *lightlist;
+  int col_defwarn;
   MAV_colour *collist;
+  int mat_defwarn;
   MAV_material *matlist;
+  int tex_defwarn;
   MAV_texture *texlist;
   MAV_texEnvFn texEnv;
+  int font_defwarn;
   MAV_font *fontlist;
 } MAV_palette;
 
@@ -326,12 +338,14 @@ typedef struct MAV_WINDOW {
   MAV_vector view;
   MAV_vector up;
   MAV_vector right;
+  int orthogonal;
   float ncp;
   float fcp;
   float fov;
   float aspect;
   float offset;
   float angle;
+  float ortho_size;
   MAV_matrix viewMat;
   MAV_matrix projMat;
   MAV_matrix pdvMat;
@@ -412,7 +426,9 @@ int  mav_windowBackfaceCullGet(MAV_window *w);
 void mav_windowBlendSet(MAV_window *w, int v);
 void mav_windowLineWidthSet(MAV_window *w, float v);
 void mav_windowLineStippleSet(MAV_window *w, int factor, unsigned short pattern);
+void mav_windowFogSet(MAV_window *w, int type, float data1, float data2, float r, float g, float b);
 void mav_windowPerspectiveSet(MAV_window *w, float ncp, float fcp, float fov, float aspect);
+void mav_windowOrthogonalSet(MAV_window *w, float ncp, float fcp, float size, float aspect);
 void mav_windowPolygonModeSet(MAV_window *w, int v);
 void mav_windowMultiSampleSet(MAV_window *w, int v);
 void mav_windowViewParamsSet(MAV_window *w, MAV_viewParams *vp);
@@ -479,6 +495,19 @@ int mav_paletteLightIndexMatchGet(MAV_palette *p, float ar, float ag, float ab,
 int mav_paletteFontIndexEmptyGet(MAV_palette *p);
 int mav_paletteFontIndexMatchGet(MAV_palette *p, char *s);
 
+void mav_paletteWarnSet(MAV_palette *p, int v);
+void mav_paletteColourWarnSet(MAV_palette *p, int v);
+void mav_paletteMaterialWarnSet(MAV_palette *p, int v);
+void mav_paletteTextureWarnSet(MAV_palette *p, int v);
+void mav_paletteLightWarnSet(MAV_palette *p, int v);
+void mav_paletteLightingModelWarnSet(MAV_palette *p, int v);
+void mav_paletteFontWarnSet(MAV_palette *p, int v);
+void mav_paletteColourIndexWarnSet(MAV_palette *p, int idx, int v);
+void mav_paletteMaterialIndexWarnSet(MAV_palette *p, int idx, int v);
+void mav_paletteTextureIndexWarnSet(MAV_palette *p, int idx, int v);
+void mav_paletteLightIndexWarnSet(MAV_palette *p, int idx, int v);
+void mav_paletteFontIndexWarnSet(MAV_palette *p, int idx, int v);
+
 MAV_surfaceParams *mav_surfaceParamsNew(int mode, int colour, int material, int texture);
 void mav_surfaceParamsUse(MAV_surfaceParams *sp);
 void mav_surfaceParamsUndefine(void);
@@ -571,11 +600,6 @@ void *mav_malloc(int amount);
 void *mav_calloc(int nelem, int elemsize);
 void mav_free(void *d);
 void mav_windowDump(MAV_window *w, char *filename);
-int  mav_stringLength(MAV_window *w, char *s, int font);
-void mav_stringDisplay(MAV_window *w, char *s, int col, int font, float x, float y);
-void mav_stringDisplayLeft(MAV_window *w, char *s, int col, int font, float x, float y);
-void mav_stringDisplayCentre(MAV_window *w, char *s, int col, int font, float x, float y);
-void mav_stringDisplayRight(MAV_window *w, char *s, int col, int font, float x, float y);
 void mav_frustumDisplay(MAV_window *w, MAV_window *f);
 void mav_sleep(float len);
 
@@ -644,6 +668,7 @@ extern int mav_opt_destAlpha;
 extern int mav_opt_fixedRnd;
 extern int mav_opt_shareContexts;
 extern int mav_opt_bindTextures;
+extern int mav_opt_syncSwap;
 extern int mav_opt_finish;
 extern int mav_opt_flush;
 
@@ -652,6 +677,7 @@ extern int mav_opt_maxMaterials;
 extern int mav_opt_maxTextures;
 extern int mav_opt_maxFonts;
 extern int mav_opt_maxLights;
+extern int mav_opt_paletteWarn;
 extern int mav_opt_mipmapping;
 extern int mav_opt_objectTableSize;
 
