@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -473,6 +473,7 @@ int mav_SMSObjIntersect(MAV_object *o, MAV_line *ln, MAV_objectIntersection *oi)
 int mav_SMSObjID(MAV_object *o, char **id);
 int mav_SMSObjGetUserdef(MAV_object *o, void ***ud);
 int mav_SMSObjGetMatrix(MAV_object *o, MAV_matrix **m);
+int mav_SMSObjGetSurfaceParams(MAV_object *o, MAV_surfaceParams ***sp);
 int mav_SMSObjDump(MAV_object *o);
 
 
