@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -46,7 +46,7 @@ extern MAV_class *mav_class_none;
 extern MAV_object *mav_object_world;
 extern MAV_object *mav_object_any;
 extern MAV_object *mav_object_none;
-typedef void (*MAV_ctrlF)(void);
+typedef void (*MAV_ctrlF)(MAV_window *);
 extern MAV_ctrlF mav_ctrlF[];
 extern char *mav_ctrlF_desc[];
 
@@ -182,6 +182,8 @@ typedef struct {
 extern MAV_callback *mav_callback_leftButton;
 extern MAV_callback *mav_callback_middleButton;
 extern MAV_callback *mav_callback_rightButton;
+extern MAV_callback *mav_callback_wheelUpButton;
+extern MAV_callback *mav_callback_wheelDownButton;
 extern MAV_callback *mav_callback_anyButton;
 typedef int (*MAV_callbackMouseFn)(MAV_object *, MAV_mouseEvent *);
 void mav_callbackMouseSet(int but, MAV_window *w, MAV_class *c, MAV_callbackMouseFn fn);
@@ -190,7 +192,9 @@ int  mav_callbackMouseExec(int but, MAV_window *w, MAV_object *o, MAV_mouseEvent
 #define MAV_LEFT_BUTTON 0
 #define MAV_MIDDLE_BUTTON 1
 #define MAV_RIGHT_BUTTON 2
-#define MAV_ANY_BUTTON 3
+#define MAV_WHEELUP_BUTTON 3
+#define MAV_WHEELDOWN_BUTTON 4
+#define MAV_ANY_BUTTON 20
 #define MAV_PRESSED 0
 #define MAV_RELEASED 1
 
