@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -382,6 +382,8 @@ void mav_HBBConstructFromSMS (MAV_SMS *hierarchy, MAV_SMS *from_sms) {
   if (mav_opt_output==MAV_VERBOSE) fprintf (stderr,
 	"Generating a HBB using %d objects.\n", nprims);
 
+  if (nprims==0) return;
+
   /* use first object to set initial root node bb */
   mav_SMSCallbackPointerResetExec (from_sms);
   mav_SMSCallbackObjectNextExec (from_sms, &this_obj);
