@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -49,59 +49,110 @@ MAV_clipPlanes mav_clipPlanesGet(MAV_window *the_win, float min_fx, float max_fx
 
   clip_planes.num= 6;
 
-  height= tan (the_win->fov/2.0*MAV_PI_OVER_180) * (the_win->ncp);
-  width= height * the_win->aspect;
+  if (the_win->orthogonal) {
+/* get orthogonal clip planes */
+    bot_left= mav_vectorAdd (the_win->eye, mav_vectorAdd (
+	mav_vectorScalar (the_win->right,
+		min_fx*0.5*the_win->ortho_size*the_win->aspect),
+	mav_vectorScalar (the_win->up, min_fy*0.5*the_win->ortho_size)));
+    top_right= mav_vectorAdd (the_win->eye, mav_vectorAdd (
+	mav_vectorScalar (the_win->right,
+		max_fx*0.5*the_win->ortho_size*the_win->aspect),
+	mav_vectorScalar (the_win->up, max_fy*0.5*the_win->ortho_size)));
 
-  centre.x= eye.x + view.x * the_win->ncp;
-  centre.y= eye.y + view.y * the_win->ncp;
-  centre.z= eye.z + view.z * the_win->ncp;
+/* compute clip planes */
 
-  bot_left.x= centre.x + width * vr.x * min_fx + height * up.x * min_fy;
-  bot_left.y= centre.y + width * vr.y * min_fx + height * up.y * min_fy;
-  bot_left.z= centre.z + width * vr.z * min_fx + height * up.z * min_fy;
+/* near */
+    clip_planes.planes[0].norm= mav_vectorScalar (the_win->view, -1.0);
+    clip_planes.planes[0].d= mav_vectorDotProduct (
+		mav_vectorAdd (
+			the_win->eye,
+			mav_vectorScalar (the_win->view, min_fz*the_win->fcp)),
+		clip_planes.planes[0].norm);
 
-  top_right.x= centre.x + width * vr.x * max_fx + height * up.x * max_fy;
-  top_right.y= centre.y + width * vr.y * max_fx + height * up.y * max_fy;
-  top_right.z= centre.z + width * vr.z * max_fx + height * up.z * max_fy;
+/* left */
+    clip_planes.planes[1].norm= mav_vectorScalar (the_win->right, -1.0);
+    clip_planes.planes[1].d= mav_vectorDotProduct (bot_left,
+		clip_planes.planes[1].norm);
 
-  /* compute clip planes */
+/* right */
+    clip_planes.planes[2].norm= the_win->right;
+    clip_planes.planes[2].d= mav_vectorDotProduct (top_right,
+		clip_planes.planes[2].norm);
 
-  /* near plane */
-  clip_planes.planes[0].norm.x= -view.x;
-  clip_planes.planes[0].norm.y= -view.y;
-  clip_planes.planes[0].norm.z= -view.z;
+/* top */
+    clip_planes.planes[3].norm= the_win->up;
+    clip_planes.planes[3].d= mav_vectorDotProduct (top_right,
+		clip_planes.planes[3].norm);
 
-  temp.x= eye.x + view.x * the_win->fcp * min_fz;
-  temp.y= eye.y + view.y * the_win->fcp * min_fz;
-  temp.z= eye.z + view.z * the_win->fcp * min_fz;
+/* bottom */
+    clip_planes.planes[4].norm= mav_vectorScalar (the_win->up, -1.0);
+    clip_planes.planes[4].d= mav_vectorDotProduct (bot_left,
+		clip_planes.planes[4].norm);
 
-  clip_planes.planes[0].d= mav_vectorDotProduct (temp, clip_planes.planes[0].norm);
+/* far */
+    clip_planes.planes[5].norm= the_win->view;
+    clip_planes.planes[5].d= mav_vectorDotProduct (
+		mav_vectorAdd (
+			the_win->eye,
+			mav_vectorScalar (the_win->view, max_fz*the_win->fcp)),
+		clip_planes.planes[5].norm);
+  } else {
+/* get perspective clip planes */
+    height= tan (the_win->fov/2.0*MAV_PI_OVER_180) * (the_win->ncp);
+    width= height * the_win->aspect;
 
-  /* left plane */
-  temp= mav_vectorSub (bot_left, eye);
-  clip_planes.planes[1].norm= mav_vectorNormalize(mav_vectorCrossProduct (up, temp));
-  clip_planes.planes[1].d= mav_vectorDotProduct (eye, clip_planes.planes[1].norm);
+    centre.x= eye.x + view.x * the_win->ncp;
+    centre.y= eye.y + view.y * the_win->ncp;
+    centre.z= eye.z + view.z * the_win->ncp;
 
-  /* right plane */
-  temp= mav_vectorSub (top_right, eye);
-  clip_planes.planes[2].norm= mav_vectorNormalize(mav_vectorCrossProduct (temp, up));
-  clip_planes.planes[2].d= mav_vectorDotProduct (eye, clip_planes.planes[2].norm);
+    bot_left.x= centre.x + width * vr.x * min_fx + height * up.x * min_fy;
+    bot_left.y= centre.y + width * vr.y * min_fx + height * up.y * min_fy;
+    bot_left.z= centre.z + width * vr.z * min_fx + height * up.z * min_fy;
 
-  /* top plane */
-  clip_planes.planes[3].norm= mav_vectorNormalize(mav_vectorCrossProduct (vr, temp));
-  clip_planes.planes[3].d= mav_vectorDotProduct (eye, clip_planes.planes[3].norm);
+    top_right.x= centre.x + width * vr.x * max_fx + height * up.x * max_fy;
+    top_right.y= centre.y + width * vr.y * max_fx + height * up.y * max_fy;
+    top_right.z= centre.z + width * vr.z * max_fx + height * up.z * max_fy;
 
-  /* bottom plane */
-  temp= mav_vectorSub (bot_left, eye);
-  clip_planes.planes[4].norm= mav_vectorNormalize(mav_vectorCrossProduct (temp, vr));
-  clip_planes.planes[4].d= mav_vectorDotProduct (eye, clip_planes.planes[4].norm);
+    /* compute clip planes */
 
-  /* far plane */
-  clip_planes.planes[5].norm= view;
-  temp.x= eye.x + view.x * the_win->fcp * max_fz;
-  temp.y= eye.y + view.y * the_win->fcp * max_fz;
-  temp.z= eye.z + view.z * the_win->fcp * max_fz;
-  clip_planes.planes[5].d= mav_vectorDotProduct (temp, view);
+    /* near plane */
+    clip_planes.planes[0].norm.x= -view.x;
+    clip_planes.planes[0].norm.y= -view.y;
+    clip_planes.planes[0].norm.z= -view.z;
+
+    temp.x= eye.x + view.x * the_win->fcp * min_fz;
+    temp.y= eye.y + view.y * the_win->fcp * min_fz;
+    temp.z= eye.z + view.z * the_win->fcp * min_fz;
+
+    clip_planes.planes[0].d= mav_vectorDotProduct (temp, clip_planes.planes[0].norm);
+
+    /* left plane */
+    temp= mav_vectorSub (bot_left, eye);
+    clip_planes.planes[1].norm= mav_vectorNormalize(mav_vectorCrossProduct (up, temp));
+    clip_planes.planes[1].d= mav_vectorDotProduct (eye, clip_planes.planes[1].norm);
+
+    /* right plane */
+    temp= mav_vectorSub (top_right, eye);
+    clip_planes.planes[2].norm= mav_vectorNormalize(mav_vectorCrossProduct (temp, up));
+    clip_planes.planes[2].d= mav_vectorDotProduct (eye, clip_planes.planes[2].norm);
+
+    /* top plane */
+    clip_planes.planes[3].norm= mav_vectorNormalize(mav_vectorCrossProduct (vr, temp));
+    clip_planes.planes[3].d= mav_vectorDotProduct (eye, clip_planes.planes[3].norm);
+
+    /* bottom plane */
+    temp= mav_vectorSub (bot_left, eye);
+    clip_planes.planes[4].norm= mav_vectorNormalize(mav_vectorCrossProduct (temp, vr));
+    clip_planes.planes[4].d= mav_vectorDotProduct (eye, clip_planes.planes[4].norm);
+
+    /* far plane */
+    clip_planes.planes[5].norm= view;
+    temp.x= eye.x + view.x * the_win->fcp * max_fz;
+    temp.y= eye.y + view.y * the_win->fcp * max_fz;
+    temp.z= eye.z + view.z * the_win->fcp * max_fz;
+    clip_planes.planes[5].d= mav_vectorDotProduct (temp, view);
+  }
 
   return clip_planes;
 }
