@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -114,8 +114,7 @@ int mav_objectIsTransparent(MAV_window *w, MAV_object *o)
 
 void mav_transparentObjectsManage(MAV_window *w, MAV_object *o, MAV_drawInfo *di)
 {
-  MAV_transObjData *to= mav_malloc(sizeof(MAV_transObjData));
-  MAV_matrix *m;
+  MAV_transObjData *to= (MAV_transObjData *) mav_malloc(sizeof(MAV_transObjData));
   MAV_vector wpos;
 
   /* store the window */
@@ -144,10 +143,11 @@ void mav_transparentObjectsManage(MAV_window *w, MAV_object *o, MAV_drawInfo *di
     to->mat= mav_gfxMatrixGet();
   }
 
-  /* store the distance squared from eye */
-  if (mav_callbackGetMatrixExec(mav_win_current, o, &m)) 
+  /* calc the bb */
+  if (mav_callbackBBExec(mav_win_current, o, &to->bb)) 
   {
-    wpos= mav_vectorMult(mav_matrixXYZGet(*m), to->mat);
+    mav_BBAlign(to->bb, to->mat, &to->bb);
+    wpos= mav_vectorScalar(mav_vectorAdd(to->bb.min, to->bb.max), 0.5);
     to->dist2= mav_vectorDotProduct(wpos, wpos);
 
     /* add to transparent object list */
@@ -156,7 +156,7 @@ void mav_transparentObjectsManage(MAV_window *w, MAV_object *o, MAV_drawInfo *di
   else
   {
     mav_free(to);
-    fprintf(stderr, "Warning: transparent object has no getmatrix callback defined, ignoring.\n");
+    fprintf(stderr, "Warning: transparent object has no BB callback defined, ignoring.\n");
   }
 }
 
@@ -209,6 +209,16 @@ void mav_transparentObjectsRender(void *ignored)
 	}
 
 	if (more) {
+#if 0
+	  /* check if object intersects with any other */
+	  mav_listPointerReset(mav_transObjList);
+	  while (mav_listItemNext(mav_transObjList, (void **) &to)) {
+	    if (to!=targ && to->win==targ->win && mav_BBIntersectsBB(to->bb, targ->bb)) {
+	      printf("Int with %x\n", to);
+	    }
+	  }
+#endif
+
 	  /* draw the object */
 	  mav_gfxMatrixLoad(targ->mat);
 	  (targ->fn)(targ->obj, targ->dip);
