@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -151,6 +151,7 @@ int mav_TDMCursorDump(MAV_object *obj)
 {
   MAV_TDMCursor *cur = (MAV_TDMCursor *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_TDMCursor with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("tracker %i\n", cur->tracker);
   printf("style %i\n", cur->style);
   mav_surfaceParamsPrint("surface params ", *cur->sp);
