@@ -21,12 +21,12 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
 
-#ifdef MAV_CYGWIN
+#ifdef __CYGWIN__
 #include <windows.h>
 #endif
 
@@ -452,7 +452,7 @@ void mavlib_TRfn3(void *ignored)
 
 /* Routine to activate TR on key press */
 
-void mavlib_cf11(void)
+void mavlib_cf11(MAV_window *w)
 {
   mav_frameFn1Add(mavlib_TRfn1, NULL);
   mav_frameFn3Add(mavlib_TRfn3, NULL);
