@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -83,7 +83,7 @@ public:
 	}
 
 	T *getNextNode() { // JMC
-	  currentNode= (CLinkedListNode<T> *)currentNode->next(); // JMC
+	  currentNode= (CLinkedListNode<T> *)currentNode->nextCircular(); // JMC
 	  return (T *) currentNode; // JMC
 	} // JMC
 	
