@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -48,7 +48,11 @@ class NormalNode : public Node {
 
 public:
 
+        MFVec3f *mf; // JMC
+
 	NormalNode () {
+	        mf=NULL; // JMC
+
 		setHeaderFlag(false);
 		setType(normalNodeString);
 
@@ -77,6 +81,10 @@ public:
 		MFVec3f *vector = (MFVec3f *)getExposedField(vectorFieldString);
 		vector->get1Value(index, value);
 	}
+	void getVectorNext(float value[]) { // JMC
+	  if (!mf) mf= (MFVec3f *)getExposedField(vectorFieldString); // JMC
+	  mf->get1ValueNext(value); // JMC
+	} // JMC
 
 	////////////////////////////////////////////////
 	//	functions
