@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -46,6 +46,7 @@ bool true=!false;
 int mav_opt_VRML97CleanUp= MAV_TRUE;
 int mav_opt_VRML97HBBThreshold= 0;
 
+MAV_SMS *mavlib_nodeObj;
 int mavlib_nodeObjCount;
 int mavlib_matScaleWarn;
 int mavlib_vrml97BoxCount;
@@ -58,6 +59,7 @@ int mavlib_vrml97IFSVertCount;
 int mavlib_vrml97ILSCount;
 int mavlib_vrml97ILSLineCount;
 int mavlib_vrml97ILSVertCount;
+int mavlib_vrml97InlineCount;
 
 /* Casts to convert generic node into a specfic type. Note that is*Node retuns true if it is */
 /* an instance node which refers to the queried note type. So, these casts need to either */
@@ -84,6 +86,13 @@ TransformNode *mavlib_castToTransformNode(Node *n)
   return rv;
 }
 
+InlineNode *mavlib_castToInlineNode(Node *n)
+{
+  InlineNode *rv= (InlineNode *) n;
+  if (n->isInstanceNode()) rv= (InlineNode *) mavlib_getReferenceNode(n);
+  return rv;
+} 
+
 SphereNode *mavlib_castToSphereNode(Node *n)
 {
   SphereNode *rv= (SphereNode *) n;
@@ -263,22 +272,22 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
   if (texc) texc_getNPoints= texc->getNPoints();
 
   if (!pts) {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: can not find the indexed face set coordinate node, ignoring\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: can not find the indexed face set coordinate node, ignoring\n");
     return NULL;
   }
 
   /* Ensure that its convex */
   if (!n->getConvex()) {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: indexed face set is concave, ignoring\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: indexed face set is concave, ignoring\n");
     return NULL;
   }
 
   /* Misc traps */
-  if (n->getColorNodes()) if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: colour not yet supported, ignoring\n");
+  if (n->getColorNodes()) if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: colour not yet supported, ignoring\n");
 
   /* Work with a local copy of the coord indexes for efficiency */
   if (n_getNCoordIndexes==0) {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: indexed face set contains no indices, ignoring\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: indexed face set contains no indices, ignoring\n");
     return NULL;
   }    
   int *coordIdx= new int[n_getNCoordIndexes];
@@ -301,7 +310,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 
   /* Work with a local copy of the points for efficiency */
   if (pts_getNPoints==0) {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: indexed face set contains no points, ignoring\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: indexed face set contains no points, ignoring\n");
     return NULL;
   }
   float *ptsIdx= new float[pts_getNPoints*3];
@@ -311,14 +320,14 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
   float *normIdx;
   if (norms) {
     normIdx= new float[norms_getNVectors*3];
-    for (i=0; i<norms_getNVectors; i++) norms->getVector(i, &normIdx[i*3]);
+    for (i=0; i<norms_getNVectors; i++) norms->getVectorNext(&normIdx[i*3]);
   }
 
   /* Work with a local copy of texture coordinates for efficiency */
   float *texcIdx;
   if (texc) {
     texcIdx= new float[texc_getNPoints*2];
-    for (i=0; i<texc_getNPoints; i++) texc->getPoint(i, &texcIdx[i*2]);
+    for (i=0; i<texc_getNPoints; i++) texc->getPointNext(&texcIdx[i*2]);
   }
 
   /* Create facet to represent the indexed face set */
@@ -368,7 +377,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	/* Ensure that the index is valid */
 	if (coordIdx[idx] >= pts_getNPoints) 
 	{
-	  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: coordinate index too big, setting to max\n");
+	  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: coordinate index too big, setting to max\n");
 	  v[0]= ptsIdx[(pts_getNPoints-1)*3+0];
 	  v[1]= ptsIdx[(pts_getNPoints-1)*3+1];
 	  v[2]= ptsIdx[(pts_getNPoints-1)*3+2];
@@ -409,7 +418,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	    /* Ensure that the index is valid */
 	    if (coordIdx[idx] >= texc_getNPoints)
 	    {
-	      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: coordinate index too big, setting to max\n");
+	      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: coordinate index too big, setting to max\n");
 	      vt[0]= texcIdx[(texc_getNPoints-1)*2+0];
 	      vt[1]= texcIdx[(texc_getNPoints-1)*2+1];
 	    }
@@ -425,7 +434,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	    int ntexidx= n->getTexCoordIndex(idx);
 	    if (ntexidx >= texc_getNPoints)
 	    {
-	      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: texture coordinate index too big, setting to max\n");
+	      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: texture coordinate index too big, setting to max\n");
 	      vt[0]= texcIdx[(texc_getNPoints-1)*2+0];
 	      vt[1]= texcIdx[(texc_getNPoints-1)*2+1];
 	    }
@@ -472,7 +481,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	      /* Ensure that the index is valid */
 	      if (coordIdx[idx] >= norms_getNVectors)
 	      {
-		if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: coordinate index too big, setting to max\n");
+		if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: coordinate index too big, setting to max\n");
 		v[0]= normIdx[(norms_getNVectors-1)*3+0];
 		v[1]= normIdx[(norms_getNVectors-1)*3+1];
 		v[2]= normIdx[(norms_getNVectors-1)*3+2];
@@ -490,7 +499,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	      int nidx= n->getNormalIndex(idx);
 	      if (nidx >= norms_getNVectors)
 	      {
-		if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: normal index too big, setting to max\n");
+		if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: normal index too big, setting to max\n");
 		v[0]= normIdx[(norms_getNVectors-1)*3+0];
 		v[1]= normIdx[(norms_getNVectors-1)*3+1];
 		v[2]= normIdx[(norms_getNVectors-1)*3+2];
@@ -528,7 +537,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	    /* Get normal - ensure index is valid */
 	    if (i >= norms_getNVectors) 
 	    {
-	      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: more faces than supplied normals, setting to max\n");
+	      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: more faces than supplied normals, setting to max\n");
 	      v[0]= normIdx[(norms_getNVectors-1)*3+0];
 	      v[1]= normIdx[(norms_getNVectors-1)*3+1];
 	      v[2]= normIdx[(norms_getNVectors-1)*3+2];
@@ -549,7 +558,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	  }
 	  else // Explicit ordering
 	  {
-	    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: indexed per-face normals not supported yet, ignoring\n");
+	    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: indexed per-face normals not supported yet, ignoring\n");
 	  }
 	}
       }
@@ -561,7 +570,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	  /* Find 2 non-parallel edge vectors */
 	  if (j==facet->np[i]-2)
 	  {
-	    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: can't find surface normal, ignoring\n");
+	    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: can't find surface normal, ignoring\n");
 	    facet->np[i]=0;
 	    v1.x= 1;
 	    v1.y= 0;
@@ -584,7 +593,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
     }    
     else
     {
-      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: face with less than 3 vertices, ignoring\n");
+      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: face with less than 3 vertices, ignoring\n");
       facet->np[i]=0;
     }
 
@@ -716,7 +725,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	    facet->tex[i][j].s= (facet->vert[i][j].z-bb.min.z)/(bb.max.z-bb.min.z);
 	    break;
 	  default:
-	    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: failed to calculate texture coordinates, ignoring\n");
+	    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: failed to calculate texture coordinates, ignoring\n");
 	    break;
 	  }
 
@@ -732,7 +741,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 	    facet->tex[i][j].t= (facet->vert[i][j].z-bb.min.z)/(bb.max.z-bb.min.z);
 	    break;
 	  default:
-	    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: failed to calculate texture coordinates, ignoring\n");
+	    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: failed to calculate texture coordinates, ignoring\n");
 	    break;
 	  }	      
 	}
@@ -740,7 +749,7 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
     }
     else
     {
-      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: failed to calculate texture coordinates, ignoring\n");
+      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: failed to calculate texture coordinates, ignoring\n");
     }
 
     facet->matrix= m; // Restore matrix
@@ -768,16 +777,16 @@ MAV_object *mavlib_dealWithIndexedLineSetNode(IndexedLineSetNode *n, MAV_surface
   if (pts) pts_getNPoints= pts->getNPoints();
 
   if (!pts) {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: can not find the indexed line set coordinate node, ignoring\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: can not find the indexed line set coordinate node, ignoring\n");
     return NULL;
   }
 
   /* Misc traps */
-  if (n->getColorNodes()) if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: colour not yet supported, ignoring\n");
+  if (n->getColorNodes()) if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: colour not yet supported, ignoring\n");
 
   /* Work with a local copy of the coord indexes for efficiency */
   if (n_getNCoordIndexes==0) {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: indexed line set contains no indices, ignoring\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: indexed line set contains no indices, ignoring\n");
     return NULL;
   }    
   int *coordIdx= new int[n_getNCoordIndexes];
@@ -800,7 +809,7 @@ MAV_object *mavlib_dealWithIndexedLineSetNode(IndexedLineSetNode *n, MAV_surface
 
   /* Work with a local copy of the points for efficiency */
   if (pts_getNPoints==0) {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: indexed line set contains no points, ignoring\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: indexed line set contains no points, ignoring\n");
     return NULL;
   }
   float *ptsIdx= new float[pts_getNPoints*3];
@@ -849,7 +858,7 @@ MAV_object *mavlib_dealWithIndexedLineSetNode(IndexedLineSetNode *n, MAV_surface
 	/* Ensure that the index is valid */
 	if (coordIdx[idx] >= pts_getNPoints) 
 	{
-	  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: coordinate index too big, setting to max\n");
+	  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: coordinate index too big, setting to max\n");
 	  v[0]= ptsIdx[(pts_getNPoints-1)*3+0];
 	  v[1]= ptsIdx[(pts_getNPoints-1)*3+1];
 	  v[2]= ptsIdx[(pts_getNPoints-1)*3+2];
@@ -871,7 +880,7 @@ MAV_object *mavlib_dealWithIndexedLineSetNode(IndexedLineSetNode *n, MAV_surface
     }    
     else
     {
-      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: line with less than 2 vertices, ignoring\n");
+      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: line with less than 2 vertices, ignoring\n");
       polyline->np[i]=0;
     }
 
@@ -890,10 +899,9 @@ MAV_object *mavlib_dealWithIndexedLineSetNode(IndexedLineSetNode *n, MAV_surface
 
 /* Routine to build a material */
 
-MAV_surfaceParams *mavlib_dealWithMaterialNode(MaterialNode *n)
+int mavlib_dealWithMaterialNode(MaterialNode *n)
 {  
   float ambientInt, diffuse[3], spec[3], emis[3], shin, trans;
-  MAV_surfaceParams *rv= mav_sp_default;
   int i;
 
   /* Get definition of material */
@@ -910,36 +918,34 @@ MAV_surfaceParams *mavlib_dealWithMaterialNode(MaterialNode *n)
 			   diffuse[0], diffuse[1], diffuse[2], 1.0-trans, spec[0], spec[1], spec[2], 1.0-trans, 
 			   emis[0], emis[1], emis[2], 1.0-trans, shin*128.0);
   
-  if (i>=0) 
-  {
-    /* You spawny get! construct and return the surface parameters */
-    rv= mav_surfaceParamsNew(MAV_MATERIAL, 0, i, 0);
-  }
-  else
+  if (i<0) 
   {
     /* No joy, find empty material index to use */
     i= mav_paletteMaterialIndexEmptyGet(mav_palette_default);
 
-    if (i>=0) {
+    if (i>=0) 
+    {
       /* Set this material */
       mav_paletteMaterialSet(mav_palette_default, i,
 			   diffuse[0]*ambientInt, diffuse[1]*ambientInt, diffuse[2]*ambientInt, 1.0-trans, 
 			   diffuse[0], diffuse[1], diffuse[2], 1.0-trans, spec[0], spec[1], spec[2], 1.0-trans, 
 			   emis[0], emis[1], emis[2], 1.0-trans, shin*128.0);
 
-      /* Construct and return the surface parameters */
-      rv= mav_surfaceParamsNew(MAV_MATERIAL, 0, i, 0);
+    }
+    else
+    {
+      i=1;
     }
   }
 
-  return rv; 
+  return i; 
 }
 
 
 
 /* Routine to build a texture */
 
-MAV_surfaceParams *mavlib_dealWithImageTextureNode(ImageTextureNode *n)
+int mavlib_dealWithImageTextureNode(ImageTextureNode *n)
 {  
   char *filename;
   int i=2;
@@ -952,7 +958,8 @@ MAV_surfaceParams *mavlib_dealWithImageTextureNode(ImageTextureNode *n)
     /* Try to find a matching index */
     i= mav_paletteTextureIndexMatchGet(mav_palette_default, filename);
 
-    if (i==-1) {
+    if (i<0) 
+    {
       /* No joy, find empty texture index to use */
       i= mav_paletteTextureIndexEmptyGet(mav_palette_default);
 
@@ -969,10 +976,10 @@ MAV_surfaceParams *mavlib_dealWithImageTextureNode(ImageTextureNode *n)
   }
   else
   {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: %i texture image URLs - dont know how to handle anything other than one\n", n->getNUrls());
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: %i texture image URLs - dont know how to handle anything other than one\n", n->getNUrls());
   }
 
-  return mav_surfaceParamsNew(MAV_TEXTURE, 0, 0, i);
+  return i;
 }
 
 
@@ -1018,16 +1025,31 @@ MAV_surfaceParams *mavlib_dealWithAppearanceNode(AppearanceNode *n, MAV_matrix *
   ImageTextureNode *tn= n->getImageTextureNodes();
   TextureTransformNode *ttn= n->getTextureTransformNodes();
   MAV_surfaceParams *rv= mav_sp_default;
+  int midx=-1, tidx=-1;
 
   /* Deal with material node if it exists */
-  if (mn) rv= mavlib_dealWithMaterialNode(mn);
+  if (mn) midx= mavlib_dealWithMaterialNode(mn);
 
   /* Deal with image texture node if it exists */
-  if (tn) rv= mavlib_dealWithImageTextureNode(tn);
+  if (tn) tidx= mavlib_dealWithImageTextureNode(tn);
 
   /* Deal with texture transform node if it exists */
   if (ttn) *texTran= mavlib_dealWithTextureTransformNode(ttn);
 
+  /* Create surface params */
+  if (mn && tn) 
+  {
+    rv= mav_surfaceParamsNew(MAV_LIT_TEXTURE, 0, midx, tidx);
+  }
+  else if (mn)
+  {
+    rv= mav_surfaceParamsNew(MAV_MATERIAL, 0, midx, 0);
+  }
+  else if (tn)
+  {
+    rv= mav_surfaceParamsNew(MAV_TEXTURE, 0, 0, tidx);
+  }
+
   return rv;
 }
 
@@ -1052,7 +1074,7 @@ MAV_object *mavlib_dealWithShapeNode(ShapeNode *n, MAV_matrix m)
   }
   else
   {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: no appearance node defined in shape - dont know if this is significant\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: no appearance node defined in shape - dont know if this is significant\n");
   }
 
   /* Deal with geometric shape */
@@ -1084,12 +1106,12 @@ MAV_object *mavlib_dealWithShapeNode(ShapeNode *n, MAV_matrix m)
     } 
     else 
     {
-      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: geometry node type %s not supported yet, ignoring\n", gn->getType());
+      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: geometry node type %s not supported yet, ignoring\n", gn->getType());
     }
   }
   else
   {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: no geometry node defined in shape - dont know if this is significant\n");
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: no geometry node defined in shape - dont know if this is significant\n");
   }
 
   return rv;
@@ -1137,6 +1159,69 @@ MAV_matrix mavlib_dealWithTransformNode(TransformNode *n)
 
 
 
+/* Routine to deal with an inline node (i.e. another vrml model) */
+ 
+MAV_object *mavlib_dealWithInlineNode(InlineNode *n, MAV_matrix m)
+{
+  char *filename;
+  MAV_object *rv= NULL;
+ 
+  if (n->getNUrls()==1)
+  {
+    MAV_composite *c= (MAV_composite *) mav_malloc(sizeof(MAV_composite));
+ 
+    /* Get filename */
+    filename= n->getUrl(0);
+
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\rBuilding objects... Object %i - inline with filename %s                  \n", mavlib_nodeObjCount, filename); 
+ 
+    /* Take a backup of the globals */
+    MAV_SMS *mavlibBK_nodeObj= mavlib_nodeObj;
+    int mavlibBK_nodeObjCount= mavlib_nodeObjCount;
+    int mavlibBK_matScaleWarn= mavlib_matScaleWarn;
+    int mavlibBK_vrml97BoxCount= mavlib_vrml97BoxCount;
+    int mavlibBK_vrml97CylinderCount= mavlib_vrml97CylinderCount;
+    int mavlibBK_vrml97ConeCount= mavlib_vrml97ConeCount;
+    int mavlibBK_vrml97SphereCount= mavlib_vrml97SphereCount;
+    int mavlibBK_vrml97IFSCount= mavlib_vrml97IFSCount;
+    int mavlibBK_vrml97IFSFaceCount= mavlib_vrml97IFSFaceCount;
+    int mavlibBK_vrml97IFSVertCount= mavlib_vrml97IFSVertCount;
+    int mavlibBK_vrml97ILSCount= mavlib_vrml97ILSCount;
+    int mavlibBK_vrml97ILSLineCount= mavlib_vrml97ILSLineCount;
+    int mavlibBK_vrml97ILSVertCount= mavlib_vrml97ILSVertCount;
+    int mavlibBK_vrml97InlineCount= mavlib_vrml97InlineCount;
+
+    if (mav_compositeRead(filename, c, m)) rv= mav_objectNew(mav_class_composite, c);
+
+    /* Restore globals */
+    mavlib_nodeObj= mavlibBK_nodeObj;
+    mavlib_nodeObjCount= mavlibBK_nodeObjCount;
+    mavlib_matScaleWarn= mavlibBK_matScaleWarn;
+    mavlib_vrml97BoxCount= mavlibBK_vrml97BoxCount;
+    mavlib_vrml97CylinderCount= mavlibBK_vrml97CylinderCount;
+    mavlib_vrml97ConeCount= mavlibBK_vrml97ConeCount;
+    mavlib_vrml97SphereCount= mavlibBK_vrml97SphereCount;
+    mavlib_vrml97IFSCount= mavlibBK_vrml97IFSCount;
+    mavlib_vrml97IFSFaceCount= mavlibBK_vrml97IFSFaceCount;
+    mavlib_vrml97IFSVertCount= mavlibBK_vrml97IFSVertCount;
+    mavlib_vrml97ILSCount= mavlibBK_vrml97ILSCount;
+    mavlib_vrml97ILSLineCount= mavlibBK_vrml97ILSLineCount;
+    mavlib_vrml97ILSVertCount= mavlibBK_vrml97ILSVertCount;
+    mavlib_vrml97InlineCount= mavlibBK_vrml97InlineCount;
+
+    if (rv) mavlib_vrml97InlineCount++;
+  }
+  else
+  {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: %i inline node URLs - dont know how to handle anything other than one\n", n->getNUrls());
+    rv= NULL;
+  }
+  
+  return rv;
+}
+
+
+
 /* Routine to deal with a node */
 
 MAV_object *mavlib_dealWithNode(Node *n, int depth, MAV_matrix matin, MAV_matrix *matout)
@@ -1149,7 +1234,7 @@ MAV_object *mavlib_dealWithNode(Node *n, int depth, MAV_matrix matin, MAV_matrix
   /* Output matrix is same as input matrix (may be changed lated by transform node) */
   *matout= matin;
 
-  /* Only concerned with shape and tranform nodes */
+  /* Only concerned with shape, tranform and inline nodes */
   if (n->isShapeNode()) 
   {
     o= mavlib_dealWithShapeNode(mavlib_castToShapeNode(n), matin);
@@ -1159,6 +1244,10 @@ MAV_object *mavlib_dealWithNode(Node *n, int depth, MAV_matrix matin, MAV_matrix
     newm= mavlib_dealWithTransformNode(mavlib_castToTransformNode(n));
     *matout= mav_matrixMult(matin, newm);
   }
+  else if (n->isInlineNode())
+  {
+    o= mavlib_dealWithInlineNode(mavlib_castToInlineNode(n), matin);
+  }
 
   return o;
 }
@@ -1167,12 +1256,11 @@ MAV_object *mavlib_dealWithNode(Node *n, int depth, MAV_matrix matin, MAV_matrix
 
 /* Routine to traverse and parse nodes and their children */
 
-MAV_SMS *mavlib_nodeObj;
-
-int mavlib_parseNode(Node *n, int depth, MAV_matrix m)
+int mavlib_parseNode(Node *n, int depth, MAV_matrix m, int lod)
 {
   MAV_object *o;
   MAV_matrix matout;
+  int rv;
 
   while (n) {
     /* Deal with this node */
@@ -1182,16 +1270,24 @@ int mavlib_parseNode(Node *n, int depth, MAV_matrix m)
     if (o) {
       mav_SMSObjectAdd(mavlib_nodeObj, o);
       mavlib_nodeObjCount++;
+
+      if (lod) {
+	if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nWarning: Using only highest LOD level, ignoring nodes at other levels\n");
+	return MAV_TRUE;
+      }
     }
 
     /* Parse its children */
-    mavlib_parseNode(n->getChildNodes(), depth+1, matout);
+    rv= mavlib_parseNode(n->getChildNodes(), depth+1, matout, lod || n->isLodNode());
+
+    /* Return up to LOD node if an object was present in the child and we're in a LOD node (or descendent) */
+    if (lod && rv) return MAV_TRUE;
 
     /* Move onto next node */
     n= n->next();
   }
 
-  return MAV_TRUE;
+  return MAV_FALSE;
 }
 
 
@@ -1227,6 +1323,7 @@ int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m)
   mavlib_vrml97ILSCount=0;
   mavlib_vrml97ILSLineCount=0;
   mavlib_vrml97ILSVertCount=0;
+  mavlib_vrml97InlineCount=0;
 
   if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Parsing VRML97 file %s... ", filename);
 
@@ -1235,7 +1332,7 @@ int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m)
   sceneGraph->load(filename, false, mavlib_VRML97LineCount, (void *) filename);
 
   if (!sceneGraph->isOK()) {
-    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\nError reading VRML97 file: reason [%s], line %d [%s], token [%s]\n", sceneGraph->getErrorReason(), sceneGraph->getErrorLineNumber(), sceneGraph->getErrorLineString(), sceneGraph->getErrorToken());
+    if (mav_opt_output==MAV_VERBOSE && sceneGraph->getErrorLineNumber()>0) fprintf(stderr, "\nError reading VRML97 file: reason [%s], line %d [%s], token [%s]\n", sceneGraph->getErrorReason(), sceneGraph->getErrorLineNumber(), sceneGraph->getErrorLineString(), sceneGraph->getErrorToken());
     return MAV_FALSE;
   }
 
@@ -1248,7 +1345,7 @@ int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m)
   /* Parse nodes and build objects */
   mavlib_nodeObjCount= 0;
   mavlib_matScaleWarn= 0;
-  mavlib_parseNode(sceneGraph->getNodes(), 0, m);
+  mavlib_parseNode(sceneGraph->getNodes(), 0, m, 0);
 
   /* Print summary */
   if (mav_opt_output==MAV_VERBOSE) {
@@ -1259,6 +1356,7 @@ int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m)
     if (mavlib_vrml97SphereCount) fprintf(stderr, " %i spheres\n", mavlib_vrml97SphereCount);
     if (mavlib_vrml97IFSCount) fprintf(stderr, " %i indexed face sets totaling %i faces and %i vertices\n", mavlib_vrml97IFSCount, mavlib_vrml97IFSFaceCount, mavlib_vrml97IFSVertCount);   
     if (mavlib_vrml97ILSCount) fprintf(stderr, " %i indexed line sets totaling %i lines and %i vertices\n", mavlib_vrml97ILSCount, mavlib_vrml97ILSLineCount, mavlib_vrml97ILSVertCount);   
+    if (mavlib_vrml97InlineCount) fprintf(stderr, " %i inlined objects\n", mavlib_vrml97InlineCount);   
     if (mavlib_matScaleWarn) fprintf(stderr, "Warning: %i objects had non-uniformly scaled matrix, this may lead to intersection problems\n", mavlib_matScaleWarn);
   }
 
