@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -150,7 +150,7 @@ void mav_avatarMove(MAV_avatar *avatar)
   dir= mav_vectorNormalize(dir);
 
   /* work out the new position */
-  vel= avatar->time*avatar->speed;
+  vel= avatar->time*avatar->speed*mav_matrixScaleGet(avatar->matrix);
   pos= mav_vectorAdd(pos, mav_vectorScalar(dir, vel));
 
   /* and update his matrix accordingly */
