@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -545,6 +545,7 @@ int mav_avatarDump(MAV_object *o)
 {
   MAV_avatar *a= (MAV_avatar *) mav_objectDataGet(o);
 
+  printf("*** Dumping object %p - a MAV_avatar with data pointer %p\n", o, mav_objectDataGet(o));
   printf("movement %i\n", a->movement);
   printf("speed %f\n", a->speed);
   printf("offset %f\n", a->offset);
