@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -29,6 +29,7 @@
 #include "maverik.h"
 #include "mav_hud.h"
 #include <math.h>
+#include <stdio.h>
 
 MAV_class *mav_class_hud;
 
@@ -39,6 +40,8 @@ void mavlib_hud2Rect(MAV_hud *hud)
   MAV_vector cent;
   float xndc, yndc, width, height;
 
+  if (mav_win_current->orthogonal && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: HUDs not supported with orthogonal projections\n");
+
   /* Orientate matrix to view */
   hud->matrix= MAV_ID_MATRIX;
   hud->matrix= mav_matrixXAxisSet(hud->matrix, mav_win_current->right);
@@ -136,18 +139,24 @@ int mav_hudDraw(MAV_object *obj, MAV_drawInfo *di)
 
 int mav_hudBB(MAV_object *obj, MAV_BB *bb)
 {
-  return 0;
+  MAV_hud *hud= (MAV_hud *) mav_objectDataGet(obj);
+
+  /* Turn the HUD into a rectangle */
+  mavlib_hud2Rect(hud);
+
+  /* Calc BB of the rectangle */
+  return mav_rectangleBB(hud->obj, bb);
 }
 
 
 
 int mav_hudIntersect(MAV_object *obj, MAV_line *ln, MAV_objectIntersection *oi)
 {
-  MAV_hud *hud= (MAV_hud*) mav_objectDataGet(obj);
+  MAV_hud *hud= (MAV_hud *) mav_objectDataGet(obj);
   int rv; 
 
   /* Turn the HUD into a rectangle */
-  mavlib_hud2Rect (hud);
+  mavlib_hud2Rect(hud);
 
   /* Intersect the rectangle */
   if (hud->selectable)
@@ -206,6 +215,28 @@ int mav_hudGetSurfaceParams(MAV_object *obj, MAV_surfaceParams ***sp)
 
 
 
+int mav_hudDump(MAV_object *obj)
+{
+  MAV_hud *hud = (MAV_hud *) mav_objectDataGet(obj);
+  int i;
+
+  printf("*** Dumping object %p - a MAV_hud with data pointer %p\n", obj, mav_objectDataGet(obj));
+  printf("nolines %i\n", hud->nolines);
+  for (i=0; i<hud->nolines; i++) printf("line %i [%s]\n", i, hud->line[i]);
+  printf("xywd %i %i %i %i\n", hud->x, hud->y, hud->w, hud->h);
+  printf("depthfac %f\n", hud->depthfac);
+  printf("text xoffset %i yoffset %i ystep %i\n", hud->textXOffset, hud->textYOffset, hud->textYStep);
+  printf("text font %i colour %i\n", hud->textFont, hud->textColour);
+  printf("selectable %i\n", hud->selectable);
+  mav_surfaceParamsPrint("surface params ", *hud->sp);
+  mav_matrixPrint("matrix (temporary)\n", hud->matrix);
+  printf("userdef %p\n", hud->userdef);
+
+  return 1;
+}
+
+
+
 MAV_hud *mav_hudNew(int nolines, int x, int y, int w, int h, MAV_surfaceParams *sp)
 {
   MAV_hud *hud= (MAV_hud *) mav_malloc(sizeof(MAV_hud));
@@ -261,6 +292,7 @@ int mav_hudModuleInit(void)
   mav_callbackGetUserdefSet(mav_win_all, mav_class_hud, mav_hudGetUserdef);
   mav_callbackGetMatrixSet(mav_win_all, mav_class_hud, mav_hudGetMatrix);
   mav_callbackGetSurfaceParamsSet(mav_win_all, mav_class_hud, mav_hudGetSurfaceParams);
+  mav_callbackDumpSet(mav_win_all, mav_class_hud, mav_hudDump);
 
   return 1;
 }
