@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -36,14 +36,14 @@
 #include "maverik.h"
 #include "mav_lwo.h"
 
-#ifdef WIN32
+#if defined(WIN32) || defined(__CYGWIN__)
 #include <windows.h>
 #endif
 #include <GL/glu.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if !defined(WIN32) || defined(MAV_CYGWIN)
+#if !defined(WIN32) || defined(__CYGWIN__)
 char *strdup (const char *s1);
 #endif
 
@@ -790,10 +790,26 @@ int mavlib_LWOBTriCount;
 int mavlib_LWOBVertCount;
 MAVLIB_LWOBTriangleList *mavlib_LWOBCurrTri;
 
+/* For old versions of GLU */
+
+#ifndef GLU_VERSION_1_2
+#define GLUtesselator GLUtriangulatorObj
+#define gluTessBeginPolygon(X,Y) gluBeginPolygon((X))
+#define gluTessBeginContour(X) gluNextContour((X), GLU_UNKNOWN)
+#define gluTessEndContour(X) 
+#define gluTessEndPolygon(X) gluEndPolygon((X))
+#endif
+
 #ifndef CALLBACK
 #define CALLBACK
 #endif
 
+#ifdef __CYGWIN__
+typedef void (*MAVLIB_GLUCB)();
+#else
+typedef void (CALLBACK *MAVLIB_GLUCB)();
+#endif
+
 void CALLBACK mavlib_LWOBTessBgn(GLenum type)
 {
     mavlib_LWOBVertCount=0;
@@ -825,7 +841,7 @@ void CALLBACK mavlib_LWOBTessEnd(void)
     }
 }
 
-void CALLBACK mavlib_LWOBTessEdge(GLboolean flag)
+void CALLBACK mavlib_LWOBTessEdge(GLboolean f)
 {
 }
 
@@ -934,13 +950,13 @@ int mav_compositeReadLWO(char *filename, MAV_composite *c, MAV_matrix mat)
 	    MAV_vector normal= current_polygon->normal;
 	    MAVLIB_LWOBPolygonList* next= current_polygon->next;
 	    MAVLIB_LWOBTriangleList *temp_tri;
-	    GLUtriangulatorObj *g=gluNewTess();
+	    GLUtesselator *g= gluNewTess();
 
-	    gluTessCallback(g, GLU_BEGIN, mavlib_LWOBTessBgn);
-	    gluTessCallback(g, GLU_VERTEX, mavlib_LWOBTessv3f);
-	    gluTessCallback(g, GLU_END, mavlib_LWOBTessEnd);
-	    gluTessCallback(g, GLU_EDGE_FLAG, mavlib_LWOBTessEdge);
-	    gluTessCallback(g, GLU_ERROR, mavlib_LWOBTessErr);
+	    gluTessCallback(g, GLU_TESS_BEGIN, (MAVLIB_GLUCB) mavlib_LWOBTessBgn);
+	    gluTessCallback(g, GLU_TESS_VERTEX, (MAVLIB_GLUCB) mavlib_LWOBTessv3f);
+	    gluTessCallback(g, GLU_TESS_END, (MAVLIB_GLUCB) mavlib_LWOBTessEnd);
+	    gluTessCallback(g, GLU_TESS_EDGE_FLAG, (MAVLIB_GLUCB) mavlib_LWOBTessEdge);
+	    gluTessCallback(g, GLU_TESS_ERROR, (MAVLIB_GLUCB) mavlib_LWOBTessErr);
 
 	    surfacesTriangulated++;
 	    
@@ -948,8 +964,8 @@ int mav_compositeReadLWO(char *filename, MAV_composite *c, MAV_matrix mat)
 	    mavlib_LWOBTriCount= 0;
 	    mavlib_LWOBVertCount= 0;
 	    
-	    gluBeginPolygon(g);
-	    gluNextContour(g, GLU_UNKNOWN);
+	    gluTessBeginPolygon(g, NULL);
+	    gluTessBeginContour(g);
 
 	    for (j=0; j<current_polygon->numverts; j++) {
 		GLdouble thisVertex[3];
@@ -962,7 +978,8 @@ int mav_compositeReadLWO(char *filename, MAV_composite *c, MAV_matrix mat)
 			      &current_polygon->vertices[j]);
 	    }
 	    
-	    gluEndPolygon(g);
+	    gluTessEndContour(g);
+	    gluTessEndPolygon(g);
 	    gluDeleteTess(g);	    
 
 	    if(mavlib_LWOBCurrTri == NULL) {
