@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -408,7 +408,7 @@ void mav_gfxColouringModeUse(MAV_palette *p, int mode)
   }
 }
 
-void mav_gfxVisualInfoGet(int *r, int *g, int *b, int *a, int *d, int *db, int *ar, int *ag, int *ab, int *aa, int *sb, int *msb)
+int mav_gfxVisualInfoGet(int *r, int *g, int *b, int *a, int *d, int *db, int *ar, int *ag, int *ab, int *aa, int *sb, int *msb)
 {
   glGetIntegerv(GL_RED_BITS, (GLint *) r);
   glGetIntegerv(GL_GREEN_BITS, (GLint *) g);
@@ -426,6 +426,8 @@ void mav_gfxVisualInfoGet(int *r, int *g, int *b, int *a, int *d, int *db, int *
 #else
   *msb=0;
 #endif
+
+  return 1;
 }
 
 void mav_gfxStripQBegin(void)
@@ -770,6 +772,47 @@ void mav_gfxLineStippleSet(int factor, unsigned short pattern)
   }
 }
 
+void mav_gfxFogSet(int type, float data1, float data2, float r, float g, float b)
+{
+  float col[4];
+  
+  col[0]=r;
+  col[1]=g;
+  col[2]=b;
+  col[3]=0;
+
+  if (type==MAV_FOG_EXP2)
+  {
+    glEnable(GL_FOG);
+    glFogi(GL_FOG_MODE, GL_EXP2);
+    glFogf(GL_FOG_DENSITY, data1);
+    glFogfv(GL_FOG_COLOR, col);
+  }
+  else if (type==MAV_FOG_EXP)
+  {
+    glEnable(GL_FOG);
+    glFogi(GL_FOG_MODE, GL_EXP);
+    glFogf(GL_FOG_DENSITY, data1);
+    glFogfv(GL_FOG_COLOR, col);
+  }
+  else if (type==MAV_FOG_LINEAR)
+  {
+    glEnable(GL_FOG);
+    glFogi(GL_FOG_MODE, GL_LINEAR);
+    glFogf(GL_FOG_START, data1);
+    glFogf(GL_FOG_END, data2);
+    glFogfv(GL_FOG_COLOR, col);
+  }
+  else if (type==MAV_FOG_NONE)
+  {
+    glDisable(GL_FOG);
+  }
+  else
+  {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Bad value when setting fog, ignoring.\n");
+  }
+}
+
 void mav_gfxBlendSet(int v)
 {
   switch (v) {
@@ -835,11 +878,13 @@ void mav_gfxListEnd(void)
 void mav_gfxListExec(int list)
 {
   glCallList(list);
+  mav_surfaceParamsUndefine();
 }
 
 void mav_gfxListsExec(int n, int *lists)
 {
   glCallLists(n, GL_INT, lists);
+  mav_surfaceParamsUndefine();
 }
 
 void mav_gfxListsDelete(int list, int range)
