@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -119,7 +119,7 @@ extern GLuint *mavlib_bindTextureIndex;
 
 
 /* Certain features only available to Cygwin users */
-#ifdef MAV_CYGWIN
+#ifdef __CYGWIN__
 #define TME 1
 #endif
 
@@ -722,15 +722,12 @@ LONG WINAPI mavlib_winEventHandler(HWND hwnd, UINT umsg, WPARAM wparam, LPARAM l
     if (mavlib_win32EventInfo[6]>='A' && mavlib_win32EventInfo[6]<='Z' && !mavlib_win32EventInfo[7]) mavlib_win32EventInfo[6]+=32;
 
     /* check for shift key and change punctuation characters */
-/*  and  work inside Maverik (when displaying text), but will */
-/* probably give different characters when outputting to a file, */
-/* or to the terminal */
     if (mavlib_win32EventInfo[7]) {
       switch (mavlib_win32EventInfo[6]) {
-	case '`': mavlib_win32EventInfo[6]= ''; break;
+	case '`': mavlib_win32EventInfo[6]= '~'; break;
         case '1': mavlib_win32EventInfo[6]= '!'; break;
         case '2': mavlib_win32EventInfo[6]= '\"'; break;
-        case '3': mavlib_win32EventInfo[6]= ''; break;
+        case '3': mavlib_win32EventInfo[6]= '#'; break;
         case '4': mavlib_win32EventInfo[6]= '$'; break;
         case '5': mavlib_win32EventInfo[6]= '%'; break;
         case '6': mavlib_win32EventInfo[6]= '^'; break;
@@ -794,6 +791,20 @@ LONG WINAPI mavlib_winEventHandler(HWND hwnd, UINT umsg, WPARAM wparam, LPARAM l
       }
     }
 
+  case 522: /* For some reason WM_MOUSEWHEEL is not defined for me */
+    if (v1==-1) {
+      short del= HIWORD(wparam);
+      if (del>0)
+      {
+	v1=4; /* wheel up */
+      }
+      else
+      {
+	v1=5; /* wheel down */
+      }
+    }
+    if (v2==-1) v2=0; /* consider it as a button press event although a release is never generated */
+
     /* The return value of this event */
     mavlib_win32EventGood=2;
 
