@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -62,6 +62,7 @@ int  mav_gfx3DfxBoardSet(int bd);
 extern int mav_opt_bindTextures;
 extern int mav_opt_shareContexts;
 extern int mav_opt_maxTextures;
+extern int mav_opt_syncSwap;
 extern int mavlib_voodoo;
 extern void *mavlib_dlh;
 extern char *mav_gfx_vendor;
@@ -418,6 +419,7 @@ void mav_gfxWindowOpen(int id, int x, int y, int width, int height, char *nm, ch
     else
     {
       mavlib_winhand[id].win= mavlib_winhand[mavlib_quadId].win;
+      mavlib_winhand[id].gfxwin= mavlib_winhand[mavlib_quadId].gfxwin;
       mavlib_winhand[id].ctx= mavlib_winhand[mavlib_quadId].ctx;
       mavlib_winhand[id].quad= mavlib_quadId;
 
@@ -509,6 +511,15 @@ void mav_gfxWindowOpen(int id, int x, int y, int width, int height, char *nm, ch
     fprintf(stderr, "Error: failed to create context\n");
     exit(1);
   }
+
+  /* synchronize swapping of multiple graphics context if requested */
+  if (mav_opt_syncSwap) {
+#if defined (GLX_SGIX_swap_group) && defined(MAV_IRIX6)
+    if (id!=1) glXJoinSwapGroupSGIX(mavlib_dpy[mavlib_winhand[id].dpy].dpy, mavlib_winhand[id].gfxwin, mavlib_winhand[1].gfxwin);
+#else
+    fprintf(stderr, "Warning: swap group extension not available, ignoring.\n");    
+#endif
+  }
   
   XFree(visinfo);
   
