@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -39,8 +39,8 @@ MAV_list *mavlib_frame3_list;
 MAV_list *mavlib_frame4_list;
 int mav_firstFrame=MAV_TRUE;
 int mav_frameCount=0;
-int mav_opt_finish=MAV_FALSE;
-int mav_opt_flush=MAV_FALSE;
+int mav_opt_finish=MAV_UNDEFINED;
+int mav_opt_flush=MAV_UNDEFINED;
 
 float mavlib_culTime=0;
 int mavlib_culFrame=0;
@@ -222,8 +222,16 @@ void mav_frameBegin(void)
     w->pdvMat= mav_matrixMult(w->projMat, w->viewMat);
 
     /* store the 5 ncp vertices */
-    vdist= tan(w->fov*0.5*MAV_PI_OVER_180)*w->ncp;
-    hdist= vdist*w->aspect;
+    if (w->orthogonal)
+    {
+      vdist= 0.5*w->ortho_size;
+      hdist= vdist*w->aspect;
+    } 
+    else 
+    {
+      vdist= tan(w->fov*0.5*MAV_PI_OVER_180)*w->ncp;
+      hdist= vdist*w->aspect;
+    }
 
     w->ncpv[4]= mav_vectorAdd(w->eye, mav_vectorScalar(w->view, w->ncp));
     w->ncpv[0]= mav_vectorAdd(w->ncpv[4], mav_vectorAdd(mav_vectorScalar(w->right, -hdist), mav_vectorScalar(w->up, -vdist)));
@@ -232,8 +240,10 @@ void mav_frameBegin(void)
     w->ncpv[3]= mav_vectorAdd(w->ncpv[4], mav_vectorAdd(mav_vectorScalar(w->right, -hdist), mav_vectorScalar(w->up, +vdist)));
 
     /* store the 5 fcp vertices */
-    vdist= tan(w->fov*0.5*MAV_PI_OVER_180)*w->fcp;
-    hdist= vdist*w->aspect;
+    if (!w->orthogonal) {
+      vdist= tan(w->fov*0.5*MAV_PI_OVER_180)*w->fcp;
+      hdist= vdist*w->aspect;
+    }
 
     w->fcpv[4]= mav_vectorAdd(w->eye, mav_vectorScalar(w->view, w->fcp));
     w->fcpv[0]= mav_vectorAdd(w->fcpv[4], mav_vectorAdd(mav_vectorScalar(w->right, -hdist), mav_vectorScalar(w->up, -vdist)));
@@ -273,16 +283,25 @@ void mav_frameEnd(void)
   mav_listPointerReset(mavlib_frame3_list);  
   while (mav_listItemsNext(mavlib_frame3_list, (void **) &fn, &d)) (*fn)(d);
 
+  /* flush and/or finish (if applicable) to sync state */
+
+  if (mav_opt_flush || mav_opt_finish) {
+    mav_listPointerReset(mav_win_list);
+    while (mav_listItemNext(mav_win_list, (void **) &w)) {
+      if (w!=mav_win_current) mav_windowSet(w);    
+      if (mav_opt_flush) mav_gfxFlush();
+      if (mav_opt_finish) mav_gfxFinish();
+    }
+  }
+
   /* swap the buffers for each window */
 
   mav_listPointerReset(mav_win_list);
 
   while (mav_listItemNext(mav_win_list, (void **) &w)) {
     if (w!=mav_win_current) mav_windowSet(w);    
-    if (mav_opt_finish) mav_gfxFinish();
-    if (mav_opt_flush) mav_gfxFlush();
     mav_gfxWindowBuffersSwap();
-  }  
+  }
 
   if (mav_win_current!=orig_win) mav_windowSet(orig_win);
 
@@ -330,157 +349,6 @@ void mav_viewParamsFixed(MAV_window *w)
 
 
 
-/* Routine to calculate the length of a string */
-
-#ifdef WIN32
-int mav_gfxWindowStringLength(int, char *, int);
-#endif
-
-int mav_stringLength(MAV_window *w, char *s, int font)
-{
-  int tot=0;
-
-#ifdef WIN32
-/* note - adding the individual widths together doesn't work */
-/* because text characters overlap */
-  tot= mav_gfxWindowStringLength(w->id, s, font);
-#else
-  int i;
-
-  if (w->palette->fontlist[font].defined) 
-  {
-    for (i=0; i<strlen(s); i++) tot+= w->palette->fontlist[font].width[(int)s[i]];
-  }
-  else
-  {
-    if (mav_opt_output) fprintf(stderr, "Warning: font %i not defined\n", font);
-  }
-#endif
-
-  return tot;
-}
-
-
-
-/* Routines to display a string on screen */
-
-int mavlib_justify=0;
-
-void mavlib_displayStringToAll(char *s, int col, int font, float x, float y)
-{
-  MAV_window *w;
-
-  mav_listPointerReset(mav_win_list);
-  
-  while (mav_listItemNext(mav_win_list, (void **) &w)) mav_stringDisplay(w,s,col,font,x,y);
-}
-
-void mav_stringDisplay(MAV_window *w, char *s, int col, int font, float x, float y)
-{
-  MAV_window *orig= mav_win_current;
-  MAV_surfaceParams sp;
-#ifndef WIN32
-  int c=0;
-#endif
-
-  if (w==mav_win_all) 
-  {
-    mavlib_displayStringToAll(s, col, font, x, y);
-  }
-  else
-  {
-    if (mav_win_current!=w) mav_windowSet(w);
-
-    /* check font has been defined */
-    if (!mav_win_current->palette->fontlist[font].defined) {
-      if (mav_opt_output) fprintf(stderr, "Warning: font %i not defined\n", font);
-    }
-
-    /* set the correct colouring */
-    sp.mode= MAV_COLOUR;
-    sp.colour= col;
-    sp.material=0;
-    sp.texture=0;
-    mav_surfaceParamsUse(&sp);
-
-    /* use a projection matrix such that we talk in term of pixels */
-    mav_gfxMatrixMode(MAV_PROJECTION);
-    mav_gfxMatrixLoad(MAV_ID_MATRIX);    
-    mav_gfxOrthogonalSet(0, mav_win_current->width, 0, mav_win_current->height, -1, 1);
-    
-    /* use an identity view matrix */
-    mav_gfxMatrixMode(MAV_MODELVIEW);
-    mav_gfxMatrixPush();
-    mav_gfxMatrixLoad(MAV_ID_MATRIX);
-    
-    /* convert position (in range [-1:1]) into pixel values */
-    x= (x+1)/2.0 * mav_win_current->width;
-    y= (y+1)/2.0 * mav_win_current->height;
-
-    /* account for justification */
-    switch (mavlib_justify) {
-    case 1: /* Center justify */
-      x-= mav_stringLength(mav_win_current, s, font)/2;
-      break;
-
-    case 2: /* Right justify */
-      x-= mav_stringLength(mav_win_current, s, font);
-      break;
-    }
-
-    /* if position is invalid (x<0), ignore a chacter and retry */
-#ifdef WIN32
-/* don't try culling as character widths are invalid */
-    mav_gfxRasterPos2DSet(x,y);
-    mav_gfxWindowStringDisplay(s, font);
-#else
-    while (x<0 && c<strlen(s)) {
-      x+= mav_win_current->palette->fontlist[font].width[(int)s[c]];
-      c++;
-    }
-
-    /* set raster position and display text (unless its all culled out) */
-    if (x>=0) {
-      mav_gfxRasterPos2DSet(x, y);
-      mav_gfxWindowStringDisplay(&s[c], font);
-    }
-#endif
-
-    /* restore original projection and view matrices */
-    mav_gfxMatrixMode(MAV_PROJECTION);
-    mav_gfxMatrixLoad(mav_win_current->projMat);
-    
-    mav_gfxMatrixMode(MAV_MODELVIEW);
-    mav_gfxMatrixPop();
-
-    if (mav_win_current!=orig) mav_windowSet(orig);
-  }
-}
-
-
-
-/* Routines to display justified text on screen */
-
-void mav_stringDisplayLeft(MAV_window *w, char *s, int col, int font, float x, float y)
-{
-  mav_stringDisplay(w, s, col, font, x, y);
-}
-
-void mav_stringDisplayCentre(MAV_window *w, char *s, int col, int font, float x, float y)
-{
-  mavlib_justify= 1;
-  mav_stringDisplay(w, s, col, font, x, y);
-  mavlib_justify= 0;
-}
-
-void mav_stringDisplayRight(MAV_window *w, char *s, int col, int font, float x, float y)
-{
-  mavlib_justify= 2;
-  mav_stringDisplay(w, s, col, font, x, y);
-  mavlib_justify= 0;
-}
-
-
 
 /* Routine to print a set of view parameters */
 
