@@ -21,20 +21,20 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
 
 #include "mavlib_kernel.h"
 #include <string.h>
-#if !defined(WIN32) || defined(MAV_CYGWIN)
+#if !defined(WIN32) || defined(__CYGWIN__)
 char *strdup (const char *s1);
 #endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
-#if defined(MAV_CYGWIN) || (!defined(WIN32) && !defined(macintosh))
+#if defined(__CYGWIN__) || (!defined(WIN32) && !defined(macintosh))
 #include <unistd.h>
 #ifdef MAV_LINUX
 #ifndef MAV_FREEBSD
@@ -80,6 +80,7 @@ int mav_this_version= MAV_THIS_VERSION;
 void *mavlib_dlh= NULL;
 int mav_opt_bindTextures= MAV_UNDEFINED;
 int mav_opt_shareContexts= MAV_UNDEFINED;
+int mav_opt_syncSwap= MAV_UNDEFINED;
 
 /* For passing options to modules. Need global vars to cope cleanly with */
 /* modules initialised from the application. */
@@ -92,7 +93,7 @@ FILE *mav_userconf= NULL;
 
 char *mav_kernelID(void)
 {
-  return "GNU Maverik v6.0";
+  return "GNU Maverik v6.1";
 }
 
 #if defined(WIN32) || defined(macintosh)
@@ -241,6 +242,42 @@ void mavlib_kernelCmdLineParse(int argc, char *argv[])
 	argv[cur_arg]= NULL;
       }
 
+      else if (strcmp(arg_name, "-flush") == 0)
+      {
+	mav_opt_flush= MAV_TRUE;
+	argv[cur_arg]= NULL;
+      }
+
+      else if (strcmp(arg_name, "-noflush") == 0)
+      {
+	mav_opt_flush= MAV_FALSE;
+	argv[cur_arg]= NULL;
+      }
+
+      else if (strcmp(arg_name, "-finish") == 0)
+      {
+	mav_opt_finish= MAV_TRUE;
+	argv[cur_arg]= NULL;
+      }
+
+      else if (strcmp(arg_name, "-nofinish") == 0)
+      {
+	mav_opt_finish= MAV_FALSE;
+	argv[cur_arg]= NULL;
+      }
+
+      else if (strcmp(arg_name, "-syncswap") == 0)
+      {
+	mav_opt_syncSwap= MAV_TRUE;
+	argv[cur_arg]= NULL;
+      }
+
+      else if (strcmp(arg_name, "-nosyncswap") == 0)
+      {
+	mav_opt_syncSwap= MAV_FALSE;
+	argv[cur_arg]= NULL;
+      }
+
       else if (strcmp(arg_name, "-mavhelp") == 0)
       {
 	printf("Maverik command line options:\n"
@@ -251,7 +288,10 @@ void mavlib_kernelCmdLineParse(int argc, char *argv[])
 	       "  -[no]singleBuf\t\t\tSingle buffered rendering\n"
 	       "  -[no]multiSample\t\t\tMultisampled rendering\n"
 	       "  -[no]shareContexts\t\t\tMultiple windows share contexts\n"
-	       "  -[no]bindTextures\t\t\tUse bound textures\n");
+	       "  -[no]bindTextures\t\t\tUse bound textures\n"
+	       "  -[no]flush\t\t\t\tPerfrom a glFlush before swapping buffers\n"
+	       "  -[no]finish\t\t\t\tPerfrom a glFinish before swapping buffers\n"
+	       "  -[no]syncSwap\t\t\t\tSynchronize swapping buffers across multiple windows\n");
 
 	/* suppress output that would otherwise disrupt the options listing */
 	mav_opt_output= MAV_SILENT;
@@ -301,6 +341,21 @@ void mavlib_kernelEnvVarsParse(void)
   {
     mav_opt_bindTextures= (strcmp(ev, "0") == 0) ? MAV_FALSE : MAV_TRUE;
   }
+
+  if ((ev= getenv("MAV_FLUSH")))
+  {
+    mav_opt_flush= (strcmp(ev, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+  }
+
+  if ((ev= getenv("MAV_FINISH")))
+  {
+    mav_opt_finish= (strcmp(ev, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+  }
+
+  if ((ev= getenv("MAV_SYNCSWAP")))
+  {
+    mav_opt_syncSwap= (strcmp(ev, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+  }
 }
 
 
@@ -353,15 +408,30 @@ void mavlib_kernelConfigFileParse(FILE *cf_file)
 	mav_opt_multiSample= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
       }
 
-      else if (strcmp(opt, "sharecontexts") == 0 && mav_opt_shareContexts == MAV_DONTCARE)
+      else if (strcmp(opt, "sharecontexts") == 0 && mav_opt_shareContexts == MAV_UNDEFINED)
       {
 	mav_opt_shareContexts= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
       }
 
-      else if (strcmp(opt, "bindtextures") == 0 && mav_opt_bindTextures == MAV_DONTCARE)
+      else if (strcmp(opt, "bindtextures") == 0 && mav_opt_bindTextures == MAV_UNDEFINED)
       {
 	mav_opt_bindTextures= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
       }
+
+      else if (strcmp(opt, "flush") == 0 && mav_opt_flush == MAV_UNDEFINED)
+      {
+	mav_opt_flush= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+      }
+
+      else if (strcmp(opt, "finish") == 0 && mav_opt_finish == MAV_UNDEFINED)
+      {
+	mav_opt_finish= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+      }
+
+      else if (strcmp(opt, "syncswap") == 0 && mav_opt_syncSwap == MAV_UNDEFINED)
+      {
+	mav_opt_syncSwap= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+      }
     }
   }
 }
@@ -375,8 +445,11 @@ void mavlib_kernelOptionsDefaultSet(void)
   if (mav_opt_fixedRnd == MAV_UNDEFINED) mav_opt_fixedRnd= MAV_FALSE;
   if (mav_opt_singleBuf == MAV_UNDEFINED) mav_opt_singleBuf= MAV_FALSE;
   if (mav_opt_WMPlacement == MAV_UNDEFINED) mav_opt_WMPlacement= MAV_FALSE;
-  if (mav_opt_bindTextures == MAV_UNDEFINED) mav_opt_bindTextures= MAV_TRUE;
   if (mav_opt_shareContexts == MAV_UNDEFINED) mav_opt_shareContexts= MAV_TRUE;
+  if (mav_opt_bindTextures == MAV_UNDEFINED) mav_opt_bindTextures= MAV_TRUE;
+  if (mav_opt_flush == MAV_UNDEFINED) mav_opt_flush= MAV_FALSE;
+  if (mav_opt_finish == MAV_UNDEFINED) mav_opt_finish= MAV_FALSE;
+  if (mav_opt_syncSwap == MAV_UNDEFINED) mav_opt_syncSwap= MAV_FALSE;
   /* leave multiSample as DONTCARE, if set as such */
 }
 
@@ -511,7 +584,7 @@ void mav_initialise(int *argc_p, char *argv[])
   /* get hostname */
 #ifdef macintosh
   strcpy(mav_hostName, "Macintosh");
-#elif defined(WIN32) && !defined(MAV_CYGWIN)
+#elif defined(WIN32) && !defined(__CYGWIN__)
   strcpy(mav_hostName, "Windows"); /* WIN32 */
 #else
   gethostname(mav_hostName, 200);
