@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -31,23 +31,23 @@
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
-#if (!defined(WIN32) || defined(MAV_CYGWIN)) && !defined(macintosh)
+#if (!defined(WIN32) || defined(__CYGWIN__)) && !defined(macintosh)
 #include <sys/types.h>
 #include <unistd.h>
 #endif
 
 
-#if !defined(WIN32) || defined(MAV_CYGWIN)
+#if !defined(WIN32) || defined(__CYGWIN__)
 char *strdup (const char *s1);
 #endif
 
 MAV_surfaceParams mavlib_surfaceParams={-1,-1,-1,-1};
 MAV_surfaceParams *mav_sp_current= &mavlib_surfaceParams;
-MAV_colour mavlib_colBlack={1,1,{0,0,0,1}};
-MAV_colour mavlib_colWhite={1,1,{1,1,1,1}};
-MAV_colour mavlib_colRed={1,1,{1,0,0,1}};
-MAV_colour mavlib_colGreen={1,1,{0,1,0,1}};
-MAV_colour mavlib_colBlue={1,1,{0,0,1,1}};
+MAV_colour mavlib_colBlack={1,1,1,{0,0,0,1}};
+MAV_colour mavlib_colWhite={1,1,1,{1,1,1,1}};
+MAV_colour mavlib_colRed={1,1,1,{1,0,0,1}};
+MAV_colour mavlib_colGreen={1,1,1,{0,1,0,1}};
+MAV_colour mavlib_colBlue={1,1,1,{0,0,1,1}};
 
 int mavlib_num_palettes= 0;
 int mavlib_use_surface_params= 1;
@@ -57,6 +57,7 @@ int mav_opt_maxMaterials=150;
 int mav_opt_maxTextures=150;
 int mav_opt_maxFonts=10;
 int mav_opt_maxLights=5;
+int mav_opt_paletteWarn= MAV_TRUE;
 int mav_opt_mipmapping=0;
 
 extern int mavlib_voodoo;
@@ -188,6 +189,15 @@ MAV_palette *mav_paletteNew(void)
   /* Add to list of palettes */
   mav_listItemAdd(mav_palette_list, (void *) rv);
 
+  /* Warn on redefinition of contents */
+  rv->defwarn= MAV_TRUE;
+  rv->lm_defwarn= MAV_TRUE;
+  rv->light_defwarn= MAV_TRUE;
+  rv->col_defwarn= MAV_TRUE;
+  rv->mat_defwarn= MAV_TRUE;
+  rv->tex_defwarn= MAV_TRUE;
+  rv->font_defwarn= MAV_TRUE;
+
  /* 
      Clear colour, material, texture and light defined lists 
      Give each a unique ID to define and bind against.
@@ -196,18 +206,21 @@ MAV_palette *mav_paletteNew(void)
   rv->collist= mav_malloc(mav_opt_maxColours*sizeof(MAV_colour));
   for (i=0; i<mav_opt_maxColours; i++) {
     rv->collist[i].id= (mavlib_num_palettes*mav_opt_maxColours)+i;
+    rv->collist[i].defwarn=MAV_TRUE;
     rv->collist[i].defined=0;
   }
 
   rv->matlist= mav_malloc(mav_opt_maxMaterials*sizeof(MAV_material));
   for (i=0; i<mav_opt_maxMaterials; i++) {
     rv->matlist[i].id= (mavlib_num_palettes*mav_opt_maxMaterials)+i;
+    rv->matlist[i].defwarn=MAV_TRUE;
     rv->matlist[i].defined=0;
   }
 
   rv->texlist= mav_malloc(mav_opt_maxTextures*sizeof(MAV_texture));
   for (i=0; i<mav_opt_maxTextures; i++) {
     rv->texlist[i].id= (mavlib_num_palettes*mav_opt_maxTextures)+i;
+    rv->texlist[i].defwarn=MAV_TRUE;
     rv->texlist[i].defined=0;
     rv->texlist[i].transparent=0;
     rv->texlist[i].mipmapped=mav_opt_mipmapping;
@@ -222,6 +235,7 @@ MAV_palette *mav_paletteNew(void)
   for (i=0; i<mav_opt_maxLights; i++) {
     rv->lightlist[i].id= (mavlib_num_palettes*mav_opt_maxLights)+i;
     rv->lightlist[i].index=i;
+    rv->lightlist[i].defwarn=MAV_TRUE;
     rv->lightlist[i].defined=0;
     rv->lightlist[i].positioning= MAV_LIGHT_RELATIVE;
   }
@@ -229,6 +243,7 @@ MAV_palette *mav_paletteNew(void)
   rv->fontlist= mav_malloc(mav_opt_maxFonts*sizeof(MAV_font));
   for (i=0; i<mav_opt_maxFonts; i++) {
     rv->fontlist[i].id= (mavlib_num_palettes*mav_opt_maxFonts)+i;
+    rv->fontlist[i].defwarn=MAV_TRUE;
     rv->fontlist[i].defined=0;
   }
 
@@ -378,7 +393,7 @@ void mav_paletteColourSet(MAV_palette *p, int index, float r, float g, float b,
 
 /* Warn if index is already defined, then define it */
 
-    if (p->collist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Colour index %i already defined in palette, overwriting\n", index);
+    if (mav_opt_paletteWarn && p->defwarn && p->col_defwarn && p->collist[index].defwarn && p->collist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Colour index %i already defined in palette, overwriting\n", index);
     
     p->collist[index].defined = MAV_REDEFINE_WARN;
     
@@ -412,7 +427,7 @@ void mav_paletteMaterialSet(MAV_palette *p, int index, float a1, float a2, float
 
 /* Warn if index is already defined, then define it */
 
-    if (p->matlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Material index %i already defined in palette, overwriting\n", index);
+    if (mav_opt_paletteWarn && p->defwarn && p->mat_defwarn && p->matlist[index].defwarn && p->matlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Material index %i already defined in palette, overwriting\n", index);
     
     p->matlist[index].defined = MAV_REDEFINE_WARN;
       
@@ -711,7 +726,7 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
     
     /* Warn if index is already defined */
     
-    if (p->texlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Texture index %i already defined in palette, overwriting\n", index);
+    if (mav_opt_paletteWarn && p->defwarn && p->tex_defwarn && p->texlist[index].defwarn && p->texlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Texture index %i already defined in palette, overwriting\n", index);
     
     /* We can read PPM and PNG directly, otherwise use ImageMagick's covert program */
     
@@ -728,7 +743,7 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
 #endif
     else
     {
-#if (!defined(WIN32) || defined(MAV_CYGWIN)) && !defined(macintosh)
+#if (!defined(WIN32) || defined(__CYGWIN__)) && !defined(macintosh)
       char buf[500], f1[500], f2[500];
       int srv;
 
@@ -787,7 +802,7 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
 	mav_free(p->texlist[index].mem);
 
 	{
-#if (!defined(WIN32) || defined(MAV_CYGWIN)) && !defined(macintosh)
+#if (!defined(WIN32) || defined(__CYGWIN__)) && !defined(macintosh)
 	  char buf[500], f1[500], f2[500];
 	  int srv;
 
@@ -988,7 +1003,7 @@ int mav_paletteTextureSetFromMem(MAV_palette *p, int index, int width, int heigh
     
     /* Warn if index is already defined */
     
-    if (p->texlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Texture index %i already defined in palette, overwriting\n", index);
+    if (mav_opt_paletteWarn && p->defwarn && p->tex_defwarn && p->texlist[index].defwarn && p->texlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Texture index %i already defined in palette, overwriting\n", index);
 
     /* Only interger powers of 2 allowed for height and width */
 
@@ -1114,7 +1129,7 @@ void mav_paletteLightSet(MAV_palette *p, int index, float a1, float a2, float a3
       
 /* Warn if index is already defined, then define it */
 
-    if (p->lightlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Light index %i already defined in palette, overwriting\n", index);
+    if (mav_opt_paletteWarn && p->defwarn && p->light_defwarn && p->lightlist[index].defwarn && p->lightlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Light index %i already defined in palette, overwriting\n", index);
     
     p->lightlist[index].defined= MAV_REDEFINE_WARN;
     p->lightlist[index].index= index;
@@ -1201,7 +1216,7 @@ void mav_paletteLightPositioning(MAV_palette *p, int index, int pos)
 
 void mav_paletteLightingModelSet(MAV_palette *p, float a1, float a2, float a3, float a4, int local_viewer)
 {
-  if (p->lm.defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Lighting model already defined in palette, overwriting\n");
+  if (mav_opt_paletteWarn && p->defwarn && p->lm_defwarn && p->lm.defwarn && p->lm.defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Lighting model already defined in palette, overwriting\n");
 
   p->lm.defined=MAV_REDEFINE_WARN;
   p->lm.ambient[0]=a1;
@@ -1283,7 +1298,7 @@ void mav_paletteFontSet(MAV_palette *p, int index, char *s)
 
 /* Warn if index is already defined, then define it */
 
-    if (p->fontlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Font index %i already defined in palette, overwriting\n", index);
+    if (mav_opt_paletteWarn && p->defwarn && p->font_defwarn && p->fontlist[index].defwarn && p->fontlist[index].defined==MAV_REDEFINE_WARN && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: Font index %i already defined in palette, overwriting\n", index);
 
     if (mav_gfxWindowFontSet(s, index, p->fontlist[index].width)!=0) 
     {
@@ -1519,3 +1534,103 @@ void mavlib_paletteDefaultValues(MAV_palette *p)
   /* Define deault sp */
   if (!mav_sp_default) mav_sp_default= mav_surfaceParamsNew(MAV_MATERIAL, 0, 1, 0);
 }
+
+
+
+/* Routines to set re-definition warning */
+
+void mav_paletteWarnSet(MAV_palette *p, int v)
+{
+  p->defwarn= v;
+}
+
+void mav_paletteColourWarnSet(MAV_palette *p, int v)
+{
+  p->col_defwarn= v;
+}
+
+void mav_paletteMaterialWarnSet(MAV_palette *p, int v)
+{
+  p->mat_defwarn= v;
+}
+
+void mav_paletteTextureWarnSet(MAV_palette *p, int v)
+{
+  p->tex_defwarn= v;
+}
+
+void mav_paletteLightWarnSet(MAV_palette *p, int v)
+{
+  p->light_defwarn= v;
+}
+
+void mav_paletteLightingModelWarnSet(MAV_palette *p, int v)
+{
+  p->lm_defwarn= v;
+}
+
+void mav_paletteFontWarnSet(MAV_palette *p, int v)
+{
+  p->font_defwarn= v;
+}
+
+void mav_paletteColourIndexWarnSet(MAV_palette *p, int index, int v)
+{
+  if (index > mav_opt_maxColours-1) 
+  {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Error: Colour index %i too big (max %i), ignoring\n", index, mav_opt_maxColours-1);
+  }
+  else
+  {
+    p->collist[index].defwarn = v;
+  }
+}
+
+void mav_paletteMaterialIndexWarnSet(MAV_palette *p, int index, int v)
+{
+  if (index > mav_opt_maxMaterials-1) 
+  {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Error: Material index %i too big (max %i), ignoring\n", index, mav_opt_maxMaterials-1);
+  }
+  else
+  {
+    p->matlist[index].defwarn = v;
+  }
+}
+
+void mav_paletteTextureIndexWarnSet(MAV_palette *p, int index, int v)
+{
+  if (index > mav_opt_maxTextures-1) 
+  {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Error: Texture index %i too big (max %i), ignoring\n", index, mav_opt_maxTextures-1);
+  }
+  else
+  {
+    p->texlist[index].defwarn = v;
+  }
+}
+
+void mav_paletteLightIndexWarnSet(MAV_palette *p, int index, int v)
+{
+  if (index > mav_opt_maxLights-1) 
+  {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Error: Light index %i too big (max %i), ignoring\n", index, mav_opt_maxLights-1);
+  }
+  else
+  {
+    p->lightlist[index].defwarn= v;
+  }
+}
+
+void mav_paletteFontIndexWarnSet(MAV_palette *p, int index, int v)
+{
+  if (index > mav_opt_maxFonts-1) 
+  {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Error: Font index %i too big (max %i), ignoring\n", index, mav_opt_maxFonts-1);
+  }
+  else
+  {
+    p->fontlist[index].defwarn= v;
+  }
+}
+
