@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -30,7 +30,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#if !defined(WIN32) || defined(MAV_CYGWIN)
+#if !defined(WIN32) || defined(__CYGWIN__)
 char *strdup (const char *s1);
 #endif
 
@@ -364,7 +364,7 @@ void mav_windowViewModifierSet(MAV_window *win, MAV_viewModifierParams *vmp, MAV
 
 /* Routines to set a windows perspective */
 
-void mavlib_setPerspectiveToAll (float ncp, float fcp, float fov, float aspect) 
+void mavlib_setPerspectiveToAll(float ncp, float fcp, float fov, float aspect) 
 {
   MAV_window *w;
 
@@ -399,6 +399,54 @@ void mav_windowPerspectiveSet(MAV_window *win, float ncp, float fcp, float fov,
     win->ncp= ncp;
     win->fcp= fcp;
 
+    /* flag as perspective projection */
+    win->orthogonal= 0;
+
+    if (curr_win != win) mav_windowSet (curr_win);
+  }
+}
+
+
+
+/* Routines to set an orthogonal projection */
+
+void mavlib_setOrthogonalToAll (float ncp, float fcp, float size, float aspect) 
+{
+  MAV_window *w;
+
+  /* step through window list setting projection */
+  mav_listPointerReset (mav_win_list);
+  while (mav_listItemNext(mav_win_list, (void **) &w)) mav_windowOrthogonalSet(w, ncp, fcp, size, aspect);
+}
+
+void mav_windowOrthogonalSet(MAV_window *win, float ncp, float fcp, float size, float aspect) 
+{
+  MAV_window *curr_win= mav_win_current;
+  
+  if (win==mav_win_all)
+  {
+    mavlib_setOrthogonalToAll (ncp, fcp, size, aspect);
+  }
+  else 
+  {
+    if (curr_win != win) mav_windowSet (win);
+
+    /* set the projection for the window */
+    mav_gfxMatrixMode(MAV_PROJECTION);
+    mav_gfxMatrixLoad(MAV_ID_MATRIX);
+    mav_gfxOrthogonalSet(-0.5*size*aspect, 0.5*size*aspect, -0.5*size, 0.5*size, ncp, fcp);
+    win->projMat= mav_gfxMatrixGet();
+    mav_gfxMatrixMode(MAV_MODELVIEW);
+
+    /* record the values */
+    win->ortho_size= size;
+    win->aspect= aspect;
+    win->ncp= ncp;
+    win->fcp= fcp;
+
+    /* flag as orthogonal */
+    win->orthogonal= 1;
+
     if (curr_win != win) mav_windowSet (curr_win);
   }
 }
@@ -529,6 +577,42 @@ void mav_windowLineStippleSet(MAV_window *win, int factor, unsigned short patter
 
 
 
+/* Routines to set a windows fog */
+
+void mavlib_setFogToAll(int tp, float d1, float d2, float r, float g, float b)
+{
+  MAV_window *w;
+
+  /* step through window list setting fog */
+  mav_listPointerReset(mav_win_list);
+  while (mav_listItemNext(mav_win_list, (void **) &w)) mav_windowFogSet(w, tp, d1, d2, r, g, b);
+}
+
+void mav_windowFogSet(MAV_window *win, int tp, float d1, float d2, float r, float g, float b)
+{
+  MAV_window *curr_win= mav_win_current;
+
+  if (win==mav_win_all) 
+  {
+    mavlib_setFogToAll(tp, d1, d2, r, g, b);
+  }
+  else
+  {
+    if (win!=curr_win) mav_windowSet(win);
+    if (r<0 && g<0 && b<0)
+    {
+      mav_gfxFogSet(tp, d1, d2, win->background_red, win->background_green, win->background_blue);
+    }
+    else
+    {
+      mav_gfxFogSet(tp, d1, d2, r, g, b);
+    }
+    if (win!=curr_win) mav_windowSet(curr_win);
+  }
+}
+
+
+
 /* Routine to dump the contents of a window as a ppm file */
 
 void mav_windowDump(MAV_window *w, char *fn)
