@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -194,7 +194,7 @@ void mav_navigationMouseDefaultParams(MAV_window *w, int but, MAV_navigatorFn x,
 extern float mavlib_keyNavLS[];
 extern float mavlib_keyNavAmount[];
 
-void mavlib_cf2(void)
+void mavlib_cf2(MAV_window *w)
 {
   int i, j;
 
@@ -215,7 +215,7 @@ void mavlib_cf2(void)
   }
 }
 
-void mavlib_cf3(void)
+void mavlib_cf3(MAV_window *w)
 {
   int i, j;
 
