@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -403,6 +403,7 @@ int mav_boxDump(MAV_object *obj)
 {
   MAV_box *box = (MAV_box *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_box with data pointer %p\n", obj, mav_objectDataGet(obj));
   mav_vectorPrint("size ", box->size);
   mav_surfaceParamsPrint("surface params ", *box->sp);
   mav_matrixPrint("matrix\n", box->matrix);
