@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -226,6 +226,7 @@ int mav_compositeDump(MAV_object *obj)
   char *s;
   int i;
 
+  printf("*** Dumping object %p - a MAV_composite with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("numobj %i\n", comp->numobj);
   for (i=0; i<comp->numobj; i++) {
     mav_callbackIDExec(mav_win_current, comp->obj[i], &s);
