@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -437,6 +437,7 @@ int mav_coneDump(MAV_object *obj)
 {
   MAV_cone *cone = (MAV_cone *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_cone with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("rt %f\n", cone->rt);
   printf("rb %f\n", cone->rb);
   printf("height %f\n", cone->height);
