@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -394,7 +394,7 @@ int mav_ctorusBB2(MAV_object *obj, MAV_BB *bb)
  */
 
 #include <math.h>
-#if (defined(WIN32) && !defined(MAV_CYGWIN)) || defined(macintosh)
+#if (defined(WIN32) && !defined(__CYGWIN__)) || defined(macintosh)
 double cbrt(double x) {return pow(x, (double)(1.0/3.0));}
 #else
 double cbrt(double x);
@@ -775,6 +775,7 @@ int mav_ctorusDump(MAV_object *obj)
 {
   MAV_ctorus *ct= (MAV_ctorus *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_ctorus with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("rmajor %f\n", ct->rmajor);
   printf("rminor %f\n", ct->rminor);
   printf("angle %f\n", ct->angle);
