@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -474,6 +474,7 @@ int mav_cylinderDump(MAV_object *obj)
 {
   MAV_cylinder *cyl = (MAV_cylinder *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_cylinder with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("radius %f\n", cyl->radius);
   printf("height %f\n", cyl->height);
   printf("nverts %i\n", cyl->nverts);
