@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -412,6 +412,7 @@ int mav_ellipseDump(MAV_object *obj)
 {
   MAV_ellipse *elip = (MAV_ellipse *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_ellipse with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("radius %f\n", elip->radius);
   printf("height %f\n", elip->height);
   printf("nverts %i\n", elip->nverts);
