@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -289,6 +289,7 @@ int mav_facetDump(MAV_object *obj)
   MAV_facet *facet = (MAV_facet *) mav_objectDataGet(obj);
   int i,j;
 
+  printf("*** Dumping object %p - a MAV_facet with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("npolys %i\n", facet->npolys);
 
   for (i=0; i<facet->npolys; i++) {
