@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -465,6 +465,7 @@ int mav_hellipseDump(MAV_object *obj)
 {
   MAV_hellipse *helip = (MAV_hellipse *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_hellipse with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("radius %f\n", helip->radius);
   printf("height %f\n", helip->height);
   printf("nverts %i\n", helip->nverts);
