@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -457,6 +457,7 @@ int mav_hsphereDump(MAV_object *obj)
 {
   MAV_hsphere *hsph = (MAV_hsphere *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_hsphere with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("radius %f\n", hsph->radius);
   printf("nverts %i\n", hsph->nverts);
   printf("nchips %i\n", hsph->nchips);
