@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -182,7 +182,7 @@ void mavlib_splash(void)
 
 /* Routine to toggle LOD */
 
-void mavlib_cf4(void)
+void mavlib_cf4(MAV_window *w)
 {
   mav_opt_curveLOD= !mav_opt_curveLOD;
   if (mav_opt_output==MAV_VERBOSE) {
@@ -535,7 +535,7 @@ int mav_objectsModuleInit(void)
   mav_callbackGetSurfaceParamsSet(mav_win_all, mav_class_polyline, mav_polylineGetSurfaceParams);
   mav_callbackGetSurfaceParamsSet(mav_win_all, mav_class_text, mav_textGetSurfaceParams);
   mav_callbackGetSurfaceParamsSet(mav_win_all, mav_class_composite, mav_compositeGetSurfaceParams);
-  mav_callbackGetSurfaceParamsSet(mav_win_all, mav_class_SMSObj, NULL);
+  mav_callbackGetSurfaceParamsSet(mav_win_all, mav_class_SMSObj, mav_SMSObjGetSurfaceParams);
   mav_callbackGetSurfaceParamsSet(mav_win_all, mav_class_teapot, mav_teapotGetSurfaceParams);
 
   /* Set their dump callbacks */
