@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -225,6 +225,7 @@ int mav_polygonDump(MAV_object *obj)
   MAV_polygon *apoly = (MAV_polygon *) mav_objectDataGet(obj);
   int i;
 
+  printf("*** Dumping object %p - a MAV_polygon with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("np %i\n", apoly->np);
   mav_vectorPrint("norm ", apoly->norm);
 
