@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -280,6 +280,7 @@ int mav_polygonGrpDump(MAV_object *obj)
   MAV_polygonGrp *polyGrp = (MAV_polygonGrp *) mav_objectDataGet(obj);
   int i,j;
 
+  printf("*** Dumping object %p - a MAV_polygonGrp with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("npolys %i\n", polyGrp->npolys);
 
   for (i=0; i<polyGrp->npolys; i++) {
