@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -195,6 +195,7 @@ int mav_polylineDump(MAV_object *obj)
   MAV_polyline *line = (MAV_polyline *) mav_objectDataGet(obj);
   int i,j;
   
+  printf("*** Dumping object %p - a MAV_polyline with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("nlines %i\n", line->nlines);
 
   for (i=0; i<line->nlines; i++) {
