@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -587,6 +587,7 @@ int mav_pyramidDump(MAV_object *obj)
 {
   MAV_pyramid *pyr = (MAV_pyramid *) mav_objectDataGet(obj);
   
+  printf("*** Dumping object %p - a MAV_pyramid with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("bot size x %f\n", pyr->bot_size_x);
   printf("bot size y %f\n", pyr->bot_size_y);
   printf("top size x %f\n", pyr->top_size_x);
