@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -261,6 +261,7 @@ int mav_rectangleDump(MAV_object *obj)
 {
   MAV_rectangle *rect= (MAV_rectangle *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_rectangle with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("width %f\n", rect->width);
   printf("height %f\n", rect->height);
   if (rect->sp->mode>=MAV_TEXTURE) {
