@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -824,6 +824,7 @@ int mav_rtorusDump(MAV_object *obj)
 {
   MAV_rtorus *rt= (MAV_rtorus *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_rtorus with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("radius %f\n", rt->radius);
   printf("width %f\n", rt->width);
   printf("height %f\n", rt->height);
