@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -186,12 +186,34 @@ int mav_SMSObjGetMatrix(MAV_object *obj, MAV_matrix **mat)
 
 
 
+/* Routine to return the surface params field of an SMS object */
+
+int mav_SMSObjGetSurfaceParams(MAV_object *obj, MAV_surfaceParams ***sp)
+{
+  MAV_SMSObj *smsobj = (MAV_SMSObj *) mav_objectDataGet(obj);
+  MAV_object *o;
+
+  mav_SMSCallbackPointerResetExec(smsobj->sms);
+  
+  if (mav_SMSCallbackObjectNextExec(smsobj->sms, &o))
+  {
+    return mav_callbackGetSurfaceParamsExec(mav_win_current, o, sp);
+  }
+  else
+  {
+    return 0;
+  }
+}
+
+
+
 /* Routine to dump an SMS object */
 
 int mav_SMSObjDump(MAV_object *obj)
 {
   MAV_SMSObj *smsobj = (MAV_SMSObj *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_SMSObj with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("dumping an SMS object\n");
   mav_matrixPrint("matrix\n", smsobj->matrix);
   printf("userdef %p\n", smsobj->userdef);
