@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -401,6 +401,7 @@ int mav_sphereDump(MAV_object *obj)
 {
   MAV_sphere *sph = (MAV_sphere *) mav_objectDataGet(obj);
 
+  printf("*** Dumping object %p - a MAV_sphere with data pointer %p\n", obj, mav_objectDataGet(obj));
   printf("radius %f\n", sph->radius);
   printf("nverts %i\n", sph->nverts);
   printf("nchips %i\n", sph->nchips);
