@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -500,6 +500,7 @@ int mav_teapotDump(MAV_object *o)
 {
   MAV_teapot *tpt = (MAV_teapot *) mav_objectDataGet(o);
 
+  printf("*** Dumping object %p - a MAV_teapot with data pointer %p\n", o, mav_objectDataGet(o));
   mav_surfaceParamsPrint("surface params ", *tpt->sp);
   mav_matrixPrint("matrix\n", tpt->matrix);
   printf("userdef %p\n", tpt->userdef);
