@@ -21,12 +21,12 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
 
-#if defined(WIN32) && !defined(MAV_CYGWIN)
+#if defined(WIN32) && !defined(__CYGWIN__)
 #pragma warning( disable : 4244 ) /* '=' : conversion from 'const double ' to 'float ', possible loss of data */
 #pragma warning( disable : 4018 ) /* '<' : signed/unsigned mismatch */
 #pragma warning( disable : 4305 ) /* '=' : truncation from 'const double ' to 'float ' */
