@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -61,39 +61,39 @@ int mav_callbackSysKeyboardExec(MAV_window *w, MAV_object *o, MAV_keyboardEvent
 
 /* Routines to implement functionality of reserved keystrokes */
 
-void mavlib_sf1(void)
+void mavlib_sf1(MAV_window *w)
 {
-  if (mav_win_current->vmp) {
-    mav_win_current->vmp->offset*=0.9;
-    fprintf(stderr, "Offset %f\n", mav_win_current->vmp->offset);
+  if (w->vmp) {
+    w->vmp->offset*=0.9;
+    fprintf(stderr, "Offset %f\n", w->vmp->offset);
   }
 }
 
-void mavlib_sf2(void)
+void mavlib_sf2(MAV_window *w)
 {
-  if (mav_win_current->vmp) {
-    mav_win_current->vmp->offset*=0.99;
-    fprintf(stderr, "Offset %f\n", mav_win_current->vmp->offset);
+  if (w->vmp) {
+    w->vmp->offset*=0.99;
+    fprintf(stderr, "Offset %f\n", w->vmp->offset);
   }
 }
 
-void mavlib_sf3(void)
+void mavlib_sf3(MAV_window *w)
 {
-  if (mav_win_current->vmp) {
-    mav_win_current->vmp->offset*=1.01;
-    fprintf(stderr, "Offset %f\n", mav_win_current->vmp->offset);
+  if (w->vmp) {
+    w->vmp->offset*=1.01;
+    fprintf(stderr, "Offset %f\n", w->vmp->offset);
   }
 }
 
-void mavlib_sf4(void)
+void mavlib_sf4(MAV_window *w)
 {
-  if (mav_win_current->vmp) {
-    mav_win_current->vmp->offset*=1.1;
-    fprintf(stderr, "Offset %f\n", mav_win_current->vmp->offset);
+  if (w->vmp) {
+    w->vmp->offset*=1.1;
+    fprintf(stderr, "Offset %f\n", w->vmp->offset);
   }
 }
 
-void mavlib_sf5(void)
+void mavlib_sf5(MAV_window *w)
 {
   MAV_viewModifierFn fn;
 
@@ -101,45 +101,52 @@ void mavlib_sf5(void)
     fn= mav_win_left->mod;
     mav_win_left->mod= mav_win_right->mod;
     mav_win_right->mod= fn;
-    fprintf (stderr, "Windows swapped\n");
+    fprintf(stderr, "Windows swapped\n");
   }
 }
 
 float mavlib_offsetbackup=0.0;
 
-void mavlib_sf6(void)
+void mavlib_sf6(MAV_window *w)
 {
-  if (mav_win_current->vmp) {
-    if (mav_win_current->vmp->offset==0.0)
+  if (w->vmp) {
+    if (w->vmp->offset==0.0)
     {
-      mav_win_current->vmp->offset=mavlib_offsetbackup;
+      w->vmp->offset= mavlib_offsetbackup;
     }
     else
     {
-      mavlib_offsetbackup=mav_win_current->vmp->offset;
-      mav_win_current->vmp->offset=0.0;
+      mavlib_offsetbackup= w->vmp->offset;
+      w->vmp->offset=0.0;
     }
     
-    fprintf(stderr, "Offset %f\n", mav_win_current->vmp->offset);
+    fprintf(stderr, "Offset %f\n", w->vmp->offset);
   }
 }
 
-void mavlib_sf7(void)
+void mavlib_sf7(MAV_window *w)
 {
   printf("\nCurrent window:\n");
-  printf(" name: %s\n", mav_win_mouse->name);
-  printf(" width: %i\n", mav_win_mouse->width);
-  printf(" height: %i\n", mav_win_mouse->height);
-  printf(" fov: %f\n", mav_win_mouse->fov);
-  printf(" apsect: %f\n", mav_win_mouse->aspect);
-  printf(" ncp: %f\n", mav_win_mouse->ncp);
-  printf(" fcp: %f\n", mav_win_mouse->fcp);
-  mav_viewParamsPrint("\nCurrent view parameters:\n", *mav_win_mouse->vp);
+  printf(" name: %s\n", w->name);
+  printf(" width: %i\n", w->width);
+  printf(" height: %i\n", w->height);
+  if (w->orthogonal)
+  {
+    printf(" ortho size: %f\n", w->ortho_size);
+  }
+  else
+  {
+    printf(" fov: %f\n", w->fov);
+  }
+  printf(" apsect: %f\n", w->aspect);
+  printf(" ncp: %f\n", w->ncp);
+  printf(" fcp: %f\n", w->fcp);
+  mav_viewParamsPrint("\nCurrent view parameters:\n", *w->vp);
 }
 
 int mavlib_filledorwire=1;
 
-void mavlib_sf8(void)
+void mavlib_sf8(MAV_window *w)
 {
   mavlib_filledorwire=!mavlib_filledorwire;
   mav_windowPolygonModeSet(mav_win_all, mavlib_filledorwire);
@@ -147,7 +154,7 @@ void mavlib_sf8(void)
 
 int mavlib_multiSample=1;
 
-void mavlib_sf9(void)
+void mavlib_sf9(MAV_window *w)
 {
   if (mav_opt_multiSample)
   {
@@ -163,7 +170,7 @@ void mavlib_sf9(void)
 
 int mavlib_drawMouse=0;
 
-void mavlib_sf10(void)
+void mavlib_sf10(MAV_window *w)
 {
   mavlib_drawMouse=!mavlib_drawMouse;
 
@@ -184,21 +191,21 @@ void mavlib_sf10(void)
 
 int mavlib_snapcnt=0;
 
-void mavlib_sf11(void)
+void mavlib_sf11(MAV_window *w)
 {
   char fn[100];
   sprintf(fn, "snap%i.ppm", mavlib_snapcnt);
-  mav_windowDump(mav_win_mouse, fn);
+  mav_windowDump(w, fn);
   mavlib_snapcnt++;
 }
 
-void mavlib_sf12(void)
+void mavlib_sf12(MAV_window *w)
 {
   int i, r, g, b, a, d, doub, ar, ag, ab, aa, sb, msb;
 
   fprintf(stderr, "\n\n");
   mav_moduleDump();
-  if (mav_win_current->vmp) {
+  if (w->vmp) {
     fprintf(stderr, "Shift-F1 decrease stereo offset by 10%%\n");
     fprintf(stderr, "Shift-F2 decrease stereo offset by 1%%\n");
     fprintf(stderr, "Shift-F3 increase stereo offset by 1%%\n");
@@ -217,22 +224,25 @@ void mavlib_sf12(void)
   for (i=0; i<15; i++) if (mav_ctrlF_desc[i]) fprintf(stderr, "%s\n", mav_ctrlF_desc[i]);
 
   fprintf(stderr, "\n");
-  if (mav_win_current->vmp) fprintf(stderr, "Current stereo offset: %f\n", mav_win_current->vmp->offset);
+  if (w->vmp) fprintf(stderr, "Current stereo offset: %f\n", w->vmp->offset);
   fprintf(stderr, "Frame rate: %f fps (%f secs per frame)\n", mav_fps_avg, 1.0/mav_fps_avg);
 
-  mav_gfxVisualInfoGet(&r, &g, &b, &a, &d, &doub, &ar, &ag, &ab, &aa, &sb, &msb);
-  fprintf(stderr, "RGBA bits: %i %i %i %i  Depth bits: %i  ", r, g, b, a, d);
-  if (doub)
-  {
-    fprintf(stderr, "Double buffered\n");
+  if (mav_gfxVisualInfoGet(&r, &g, &b, &a, &d, &doub, &ar, &ag, &ab, &aa, &sb, &msb)) {
+    fprintf(stderr, "RGBA bits: %i %i %i %i  Depth bits: %i  ", r, g, b, a, d);
+    if (doub)
+    {
+      fprintf(stderr, "Double buffered\n");
+    }
+    else
+    {
+      fprintf(stderr, "Single buffered\n");
+    }
+
+    if (mav_opt_accumBuf) fprintf(stderr, "Accumulation RGBA bits: %i %i %i %i\n", ar, ag, ab, aa);
+    if (mav_opt_stencilBuf) fprintf(stderr, "Stencil bits: %i\n", sb);
+    if (mav_opt_multiSample) fprintf(stderr, "Multisamples: %i\n", msb);
   }
-  else
-  {
-    fprintf(stderr, "Single buffered\n");
-  }
-  if (mav_opt_accumBuf) fprintf(stderr, "Accumulation RGBA bits: %i %i %i %i\n", ar, ag, ab, aa);
-  if (mav_opt_stencilBuf) fprintf(stderr, "Stencil bits: %i\n", sb);
-  if (mav_opt_multiSample) fprintf(stderr, "Multisamples: %i\n", msb);
+
   if (mav_gfx_vendor) fprintf(stderr, "Vendor: %s\n", mav_gfx_vendor);
   if (mav_gfx_renderer) fprintf(stderr, "Renderer: %s\n", mav_gfx_renderer);
   if (mav_gfx_version) fprintf(stderr, "Version: %s\n", mav_gfx_version);
@@ -280,25 +290,25 @@ int mavlib_dealWithKeyboardEvent(int *info)
   /* Check for reserved keystrokes */
 
   if (ke.movement==MAV_PRESSED && ke.modifiers[MAV_MODIFIER_SHIFT]==MAV_PRESSED) {
-    if (ke.key==MAV_KEY_F1) {mavlib_sf1(); return -100;}
-    if (ke.key==MAV_KEY_F2) {mavlib_sf2(); return -100;}
-    if (ke.key==MAV_KEY_F3) {mavlib_sf3(); return -100;}
-    if (ke.key==MAV_KEY_F4) {mavlib_sf4(); return -100;}
-    if (ke.key==MAV_KEY_F5) {mavlib_sf5(); return -100;}
-    if (ke.key==MAV_KEY_F6) {mavlib_sf6(); return -100;}
-    if (ke.key==MAV_KEY_F7) {mavlib_sf7(); return -100;}
-    if (ke.key==MAV_KEY_F8) {mavlib_sf8(); return -100;}
-    if (ke.key==MAV_KEY_F9) {mavlib_sf9(); return -100;}
-    if (ke.key==MAV_KEY_F10) {mavlib_sf10(); return -100;}
-    if (ke.key==MAV_KEY_F11) {mavlib_sf11(); return -100;}
-    if (ke.key==MAV_KEY_F12) {mavlib_sf12(); return -100;}
+    if (ke.key==MAV_KEY_F1) {mavlib_sf1(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F2) {mavlib_sf2(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F3) {mavlib_sf3(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F4) {mavlib_sf4(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F5) {mavlib_sf5(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F6) {mavlib_sf6(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F7) {mavlib_sf7(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F8) {mavlib_sf8(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F9) {mavlib_sf9(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F10) {mavlib_sf10(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F11) {mavlib_sf11(ke.win); return -100;}
+    if (ke.key==MAV_KEY_F12) {mavlib_sf12(ke.win); return -100;}
     if (ke.key==27) exit(1);
   }
 
   if (ke.movement==MAV_PRESSED && ke.modifiers[MAV_MODIFIER_CTRL]==MAV_PRESSED) {
     for (i=1; i<=12; i++) {
       if (ke.key==MAV_KEY_F1+i-1 && mav_ctrlF[i]) {
-	(*mav_ctrlF[i])();
+	(*mav_ctrlF[i])(ke.win);
 	return -100;
       }
     }
