@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -32,6 +32,8 @@
 MAV_callback *mav_callback_leftButton;
 MAV_callback *mav_callback_middleButton;
 MAV_callback *mav_callback_rightButton;
+MAV_callback *mav_callback_wheelUpButton;
+MAV_callback *mav_callback_wheelDownButton;
 MAV_callback *mav_callback_anyButton;
 MAV_callback *mav_callback_sysMouse;
 
@@ -51,6 +53,12 @@ void mav_callbackMouseSet(int button, MAV_window *w, MAV_class *c, MAV_callbackM
   case MAV_RIGHT_BUTTON:
     mav_callbackSet(mav_callback_rightButton, w, c, (MAV_callbackFn) fn);
     break;
+  case MAV_WHEELUP_BUTTON:
+    mav_callbackSet(mav_callback_wheelUpButton, w, c, (MAV_callbackFn) fn);
+    break;
+  case MAV_WHEELDOWN_BUTTON:
+    mav_callbackSet(mav_callback_wheelDownButton, w, c, (MAV_callbackFn) fn);
+    break;
   case MAV_ANY_BUTTON:
     mav_callbackSet(mav_callback_anyButton, w, c, (MAV_callbackFn) fn);
     break;
@@ -74,6 +82,12 @@ int mav_callbackMouseExec(int button, MAV_window *w, MAV_object *o, MAV_mouseEve
   case MAV_RIGHT_BUTTON:
     rv= mav_callbackExec(mav_callback_rightButton, w, o, (void *) me, NULL);
     break;
+  case MAV_WHEELUP_BUTTON:
+    rv= mav_callbackExec(mav_callback_wheelUpButton, w, o, (void *) me, NULL);
+    break;
+  case MAV_WHEELDOWN_BUTTON:
+    rv= mav_callbackExec(mav_callback_wheelDownButton, w, o, (void *) me, NULL);
+    break;
   case MAV_ANY_BUTTON:
     rv= mav_callbackExec(mav_callback_anyButton, w, o, (void *) me, NULL);
     break;
@@ -137,6 +151,14 @@ int mavlib_dealWithMouseEvent(int *info)
     me.button= MAV_RIGHT_BUTTON;
     bc= mav_callback_rightButton;
     break;
+  case 4:
+    me.button= MAV_WHEELUP_BUTTON;
+    bc= mav_callback_wheelUpButton;
+    break;
+  case 5:
+    me.button= MAV_WHEELDOWN_BUTTON;
+    bc= mav_callback_wheelDownButton;
+    break;
   default:
     return rv;
   }
@@ -246,7 +268,7 @@ int mavlib_dealWithMouseEvent(int *info)
 
 void mav_mouseGet(MAV_window *win, int *x, int *y, int *rx, int *ry, int *buts)
 {
-#if defined(macintosh) || defined(WIN32)
+#if defined(macintosh) || (defined(WIN32) && !defined(__CYGWIN__))
   if (buts && mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: polling of mouse buttons not supported\n");
 #endif
 
@@ -276,21 +298,21 @@ void mav_mouseDraw(void *ignored)
 
     mav_gfxLineBegin();
 #ifdef WIN32
-    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->vp->trans_right, -100.0)));
-    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->vp->trans_right, +100.0)));
+    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->right, -100.0)));
+    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->right, +100.0)));
 #else
-    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->vp->trans_right, -10000.0)));
-    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->vp->trans_right, +10000.0)));
+    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->right, -10000.0)));
+    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->right, +10000.0)));
 #endif
     mav_gfxLineEnd();
     
     mav_gfxLineBegin();
 #ifdef WIN32
-    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->vp->trans_up, -100.0)));
-    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->vp->trans_up, +100.0)));
+    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->up, -100.0)));
+    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->up, +100.0)));
 #else
-    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->vp->trans_up, -10000.0)));
-    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->vp->trans_up, +10000.0)));
+    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->up, -10000.0)));
+    mav_gfxVertex(mav_vectorAdd(mav_mouse_pos, mav_vectorScalar(mav_win_current->up, +10000.0)));
 #endif
     mav_gfxLineEnd();
     
