@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -69,14 +69,21 @@ int mav_resizeDefault(MAV_object *obj, MAV_resizeEvent *ev)
 {
   MAV_window *orig_win= mav_win_current;
   
-  /* resize window keeping the same field of view */
+  /* resize window keeping the same field of view or orthogonal size */
 
   if (ev->win!=mav_win_current) mav_windowSet(ev->win);
 
-  mav_gfxViewPortSet(0,0,ev->width,ev->height);
   ev->win->width= ev->width;
   ev->win->height= ev->height;
-  mav_windowPerspectiveSet(ev->win, ev->win->ncp, ev->win->fcp, ev->win->fov, ((float) ev->width)/ev->height);
+  mav_gfxViewPortSet(0,0,ev->width,ev->height);
+  if (ev->win->orthogonal)
+  {
+    mav_windowOrthogonalSet(ev->win, ev->win->ncp, ev->win->fcp, ev->win->ortho_size, ((float) ev->width)/ev->height);
+  }
+  else
+  {
+    mav_windowPerspectiveSet(ev->win, ev->win->ncp, ev->win->fcp, ev->win->fov, ((float) ev->width)/ev->height);
+  }
 
   if (mav_win_current!=orig_win) mav_windowSet(orig_win);
 
