@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -36,12 +36,12 @@
 #include <dlfcn.h>
 #endif
 #include <string.h>
-#if (!defined(WIN32) || defined(MAV_CYGWIN)) && !defined(macintosh)
+#if (!defined(WIN32) || defined(__CYGWIN__)) && !defined(macintosh)
 #include <sys/types.h>
 #include <unistd.h>
 #endif
 
-#if !defined(WIN32) || defined(MAV_CYGWIN)
+#if !defined(WIN32) || defined(__CYGWIN__)
 char *strdup(const char *);
 #endif
 
@@ -201,7 +201,7 @@ void mavlib_restrictMouse(void *ignored)
 int mavlib_fullscreen=1;
 int mavlib_restrictMouseOpt=0;
 
-void mavlib_cf1(void)
+void mavlib_cf1(MAV_window *win)
 {
   MAV_window *o, *w;
   
@@ -230,47 +230,91 @@ void mavlib_cf1(void)
 
 
 
-void mavlib_cf5(void)
+void mavlib_cf5(MAV_window *w)
 {
-  mav_windowPerspectiveSet(mav_win_mouse, mav_win_mouse->ncp*0.9, mav_win_mouse->fcp, mav_win_mouse->fov, mav_win_mouse->aspect);
-  printf("Near clip plane now at %f\n", mav_win_mouse->ncp);
+  if (w->orthogonal)
+  {
+    mav_windowOrthogonalSet(w, w->ncp*0.9, w->fcp, w->ortho_size, w->aspect);
+  }
+  else
+  {
+    mav_windowPerspectiveSet(w, w->ncp*0.9, w->fcp, w->fov, w->aspect);
+  }
+  printf("Near clip plane now at %f\n", w->ncp);
 }
 
-void mavlib_cf6(void)
+void mavlib_cf6(MAV_window *w)
 {
-  mav_windowPerspectiveSet(mav_win_mouse, mav_win_mouse->ncp*1.1, mav_win_mouse->fcp, mav_win_mouse->fov, mav_win_mouse->aspect);
-  printf("Near clip plane now at %f\n", mav_win_mouse->ncp);
+  if (w->orthogonal)
+  {
+    mav_windowOrthogonalSet(w, w->ncp*1.1, w->fcp, w->ortho_size, w->aspect);
+  }
+  else
+  {
+    mav_windowPerspectiveSet(w, w->ncp*1.1, w->fcp, w->fov, w->aspect);
+  }
+  printf("Near clip plane now at %f\n", w->ncp);
 }
 
-void mavlib_cf7(void)
+void mavlib_cf7(MAV_window *w)
 {
-  mav_windowPerspectiveSet(mav_win_mouse, mav_win_mouse->ncp, mav_win_mouse->fcp*0.9, mav_win_mouse->fov, mav_win_mouse->aspect);
-  printf("Far clip plane now at %f\n", mav_win_mouse->fcp);
+  if (w->orthogonal)
+  {
+    mav_windowOrthogonalSet(w, w->ncp, w->fcp*0.9, w->ortho_size, w->aspect);
+  }
+  else
+  {
+    mav_windowPerspectiveSet(w, w->ncp, w->fcp*0.9, w->fov, w->aspect);
+  }
+  printf("Far clip plane now at %f\n", w->fcp);
 }
 
-void mavlib_cf8(void)
+void mavlib_cf8(MAV_window *w)
 {
-  mav_windowPerspectiveSet(mav_win_mouse, mav_win_mouse->ncp, mav_win_mouse->fcp*1.1, mav_win_mouse->fov, mav_win_mouse->aspect);
-  printf("Far clip plane now at %f\n", mav_win_mouse->fcp);
+  if (w->orthogonal)
+  {
+    mav_windowOrthogonalSet(w, w->ncp, w->fcp*1.1, w->ortho_size, w->aspect);
+  }
+  else
+  {
+    mav_windowPerspectiveSet(w, w->ncp, w->fcp*1.1, w->fov, w->aspect);
+  }
+  printf("Far clip plane now at %f\n", w->fcp);
 }
 
-void mavlib_cf9(void)
+void mavlib_cf9(MAV_window *w)
 {
-  mav_windowPerspectiveSet(mav_win_mouse, mav_win_mouse->ncp, mav_win_mouse->fcp, mav_win_mouse->fov*0.9, mav_win_mouse->aspect);
-  printf("Field of view now at %f\n", mav_win_mouse->fov);
+  if (w->orthogonal)
+  {
+    mav_windowOrthogonalSet(w, w->ncp, w->fcp, w->ortho_size*0.9, w->aspect);
+    printf("Orthogonal size now at %f\n", w->ortho_size);
+  }
+  else
+  {
+    mav_windowPerspectiveSet(w, w->ncp, w->fcp, w->fov*0.9, w->aspect);
+    printf("Field of view now at %f\n", w->fov);
+  }
 }
 
-void mavlib_cf10(void)
+void mavlib_cf10(MAV_window *w)
 {
-  mav_windowPerspectiveSet(mav_win_mouse, mav_win_mouse->ncp, mav_win_mouse->fcp, mav_win_mouse->fov*1.1, mav_win_mouse->aspect);
-  printf("Field of view now at %f\n", mav_win_mouse->fov);
+  if (w->orthogonal)
+  {
+    mav_windowOrthogonalSet(w, w->ncp, w->fcp, w->ortho_size*1.1, w->aspect);
+    printf("Orthogonal size now at %f\n", w->ortho_size);
+  }
+  else
+  {
+    mav_windowPerspectiveSet(w, w->ncp, w->fcp, w->fov*1.1, w->aspect);
+    printf("Field of view now at %f\n", w->fov);
+  }
 }
 
 
 
 /* Reserved Ctrl F12 keypress */
 
-void mavlib_cf12(void)
+void mavlib_cf12(MAV_window *w)
 {
 #if defined(WIN32) || defined(macintosh)
   fprintf(stderr, "Warning: dynamic loading of modules is not supported under this OS, ignoring\n"); /* WIN32 */
@@ -777,7 +821,7 @@ char *mav_windowsModuleID(void)
 
 int mav_windowsModuleInit(void)
 {
-#if !defined(WIN32) || defined(MAV_CYGWIN)
+#if !defined(WIN32) || defined(__CYGWIN__)
   FILE *f;
   char filename[500];
 #endif
@@ -812,6 +856,8 @@ int mav_windowsModuleInit(void)
   mav_callback_leftButton= mav_callbackNew();
   mav_callback_middleButton= mav_callbackNew();
   mav_callback_rightButton= mav_callbackNew();
+  mav_callback_wheelUpButton= mav_callbackNew();
+  mav_callback_wheelDownButton= mav_callbackNew();
   mav_callback_anyButton= mav_callbackNew();
   mav_callback_sysMouse= mav_callbackNew();
   mav_callback_resize= mav_callbackNew();
@@ -848,10 +894,10 @@ int mav_windowsModuleInit(void)
   mav_ctrlF_desc[8]= "Ctrl-F8 increase far clipping plane by 10%";
 
   mav_ctrlF[9]= mavlib_cf9;
-  mav_ctrlF_desc[9]= "Ctrl-F9 decrease field of view by 10%";
+  mav_ctrlF_desc[9]= "Ctrl-F9 decrease field of view/orthogonal size by 10%";
 
   mav_ctrlF[10]= mavlib_cf10;
-  mav_ctrlF_desc[10]= "Ctrl-F10 increase field of view by 10%";
+  mav_ctrlF_desc[10]= "Ctrl-F10 increase field of view/orthogonal size by 10%";
 
   mav_ctrlF[12]= mavlib_cf12;
   mav_ctrlF_desc[12]= "Ctrl-F12 load a module on the fly";
@@ -1007,12 +1053,12 @@ int mav_windowsModuleInit(void)
     }
     else
     {
-#if (defined(WIN32) && !defined(MAV_CYGWIN)) || defined(macintosh)
+#if (defined(WIN32) && !defined(__CYGWIN__)) || defined(macintosh)
       strcpy(buf, "Maverik"); /* WIN32 */
 #else
       sprintf(filename, "/tmp/mavname%i", getpid());
-#ifdef MAV_CYGWIN
-      sprintf (buf, "ps a | awk '{if ($1==%i) print $4}' 2>&1 >%s", getpid(), filename);
+#ifdef __CYGWIN__
+      sprintf (buf, "ps a | awk '{if ($1==%i) print $8}' 2>&1 >%s", getpid(), filename);
 #else
 #ifdef MAV_LINUX
       sprintf(buf, "ps a | awk '{if ($1==%i) print $5}' 2>&1 >%s", getpid(), filename);
@@ -1026,7 +1072,7 @@ int mav_windowsModuleInit(void)
       if (f) 
       {
 	if (fscanf(f, "%s", buf)!=1) strcpy(buf, "Maverik");
-#ifdef MAV_CYGWIN
+#ifdef __CYGWIN__
         else {
 	  int last_slash= -1;
 	  int i= 0;
@@ -1147,7 +1193,7 @@ MAV_window *mavlib_getWindow(int id)
 
 
 
-/* Routine to calculate a line from a the mouse's position */
+/* Routine to calculate a line through a the mouse's position */
 
 MAV_line mav_lineFrom2DPoint(MAV_window *w, int x, int y)
 {
@@ -1155,21 +1201,35 @@ MAV_line mav_lineFrom2DPoint(MAV_window *w, int x, int y)
   MAV_vector up, right;
   float width, height, rx, ry;
 
-  ln.pt= w->eye;
-
   /* get x and y in range 0.0 to 1.0 */
   rx= ((float) x)/w->width;
   ry= ((float) y)/w->height;
 
-  /* get size of window */
-  height= tan(w->fov*0.5*MAV_PI_OVER_180)*2.0;
-  width= height * w->aspect;
-  
-  right= mav_vectorScalar(w->right, width*(rx-0.5));
-  up= mav_vectorScalar(w->up, -height*(ry-0.5));
+  if (w->orthogonal) 
+  {
+    /* get size of window */
+    height= w->ortho_size;
+    width= height * w->aspect;
 
-  ln.dir= mav_vectorAdd(w->view, mav_vectorAdd(right, up));
-  ln.dir= mav_vectorNormalize(ln.dir);
+    right= mav_vectorScalar(w->right, width*(rx-0.5));
+    up= mav_vectorScalar(w->up, -height*(ry-0.5));
+
+    ln.pt= mav_vectorAdd(w->eye, mav_vectorAdd(right, up));
+    ln.dir= w->view;
+  } 
+  else 
+  {
+    /* get size of window */
+    height= tan(w->fov*0.5*MAV_PI_OVER_180)*2.0;
+    width= height * w->aspect;
+  
+    right= mav_vectorScalar(w->right, width*(rx-0.5));
+    up= mav_vectorScalar(w->up, -height*(ry-0.5));
+
+    ln.pt= w->eye;
+    ln.dir= mav_vectorAdd(w->view, mav_vectorAdd(right, up));
+    ln.dir= mav_vectorNormalize(ln.dir);
+  }
 
   return ln;
 }
